/********************************************************************************
** Form generated from reading UI file 'CertDetail.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CERTDETAIL_H
#define UI_CERTDETAIL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/clicklabel.h"
#include "widgets/distname.h"

QT_BEGIN_NAMESPACE

class Ui_CertDetail
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *headerLabel;
    QSpacerItem *spacerItem;
    QLabel *image;
    QTabWidget *tabwidget;
    QWidget *statusTab;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *spacerItem1;
    QFrame *frame;
    QGridLayout *gridLayout;
    QLabel *TextLabel2;
    QLineEdit *description;
    QLabel *signedLabel;
    QHBoxLayout *horizontalLayout;
    ClickLabel *signature;
    CopyLabel *sigAlgo;
    QLabel *TextLabel6;
    ClickLabel *privKey;
    QLabel *serialLabel;
    CopyLabel *serialNr;
    QGroupBox *fingerprints;
    QGridLayout *gridLayout1;
    QLabel *TextLabel1_2;
    CopyLabel *fpMD5;
    QLabel *TextLabel2_2;
    CopyLabel *fpSHA1;
    QLabel *TextLabel2_3;
    CopyLabel *fpSHA256;
    QGroupBox *validity;
    QHBoxLayout *hboxLayout1;
    CopyLabel *notBefore;
    CopyLabel *notAfter;
    ClickLabel *dateValid;
    QSpacerItem *spacerItem2;
    QWidget *subjectTab;
    QVBoxLayout *vboxLayout;
    DistName *subject;
    QWidget *issuerTab;
    QVBoxLayout *vboxLayout1;
    DistName *issuer;
    QWidget *attributesTab;
    QVBoxLayout *verticalLayout_3;
    QWidget *attributes;
    QWidget *extensionsTab;
    QVBoxLayout *verticalLayout;
    QTextEdit *v3extensions;
    QPushButton *showExt;
    QWidget *validationTab;
    QVBoxLayout *verticalLayout_6;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_10;
    QListWidget *purposeList;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_11;
    QTextEdit *validation;
    QWidget *commentTab;
    QVBoxLayout *verticalLayout_5;
    QTextEdit *comment;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CertDetail)
    {
        if (CertDetail->objectName().isEmpty())
            CertDetail->setObjectName("CertDetail");
        CertDetail->resize(712, 502);
        verticalLayout_2 = new QVBoxLayout(CertDetail);
        verticalLayout_2->setObjectName("verticalLayout_2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        headerLabel = new QLabel(CertDetail);
        headerLabel->setObjectName("headerLabel");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        headerLabel->setFont(font);

        hboxLayout->addWidget(headerLabel);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(CertDetail);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout_2->addLayout(hboxLayout);

        tabwidget = new QTabWidget(CertDetail);
        tabwidget->setObjectName("tabwidget");
        statusTab = new QWidget();
        statusTab->setObjectName("statusTab");
        verticalLayout_4 = new QVBoxLayout(statusTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem1);

        frame = new QFrame(statusTab);
        frame->setObjectName("frame");
        frame->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        TextLabel2 = new QLabel(frame);
        TextLabel2->setObjectName("TextLabel2");

        gridLayout->addWidget(TextLabel2, 0, 0, 1, 1);

        description = new QLineEdit(frame);
        description->setObjectName("description");

        gridLayout->addWidget(description, 0, 1, 1, 1);

        signedLabel = new QLabel(frame);
        signedLabel->setObjectName("signedLabel");

        gridLayout->addWidget(signedLabel, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        signature = new ClickLabel(frame);
        signature->setObjectName("signature");

        horizontalLayout->addWidget(signature);

        sigAlgo = new CopyLabel(frame);
        sigAlgo->setObjectName("sigAlgo");

        horizontalLayout->addWidget(sigAlgo);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 1);

        TextLabel6 = new QLabel(frame);
        TextLabel6->setObjectName("TextLabel6");

        gridLayout->addWidget(TextLabel6, 2, 0, 1, 1);

        privKey = new ClickLabel(frame);
        privKey->setObjectName("privKey");

        gridLayout->addWidget(privKey, 2, 1, 1, 1);

        serialLabel = new QLabel(frame);
        serialLabel->setObjectName("serialLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(serialLabel->sizePolicy().hasHeightForWidth());
        serialLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(serialLabel, 3, 0, 1, 1);

        serialNr = new CopyLabel(frame);
        serialNr->setObjectName("serialNr");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(serialNr->sizePolicy().hasHeightForWidth());
        serialNr->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(serialNr, 3, 1, 1, 1);


        verticalLayout_4->addWidget(frame);

        fingerprints = new QGroupBox(statusTab);
        fingerprints->setObjectName("fingerprints");
        gridLayout1 = new QGridLayout(fingerprints);
        gridLayout1->setObjectName("gridLayout1");
        TextLabel1_2 = new QLabel(fingerprints);
        TextLabel1_2->setObjectName("TextLabel1_2");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(TextLabel1_2->sizePolicy().hasHeightForWidth());
        TextLabel1_2->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(TextLabel1_2, 0, 0, 1, 1);

        fpMD5 = new CopyLabel(fingerprints);
        fpMD5->setObjectName("fpMD5");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(fpMD5->sizePolicy().hasHeightForWidth());
        fpMD5->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(fpMD5, 0, 1, 1, 1);

        TextLabel2_2 = new QLabel(fingerprints);
        TextLabel2_2->setObjectName("TextLabel2_2");
        sizePolicy2.setHeightForWidth(TextLabel2_2->sizePolicy().hasHeightForWidth());
        TextLabel2_2->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(TextLabel2_2, 1, 0, 1, 1);

        fpSHA1 = new CopyLabel(fingerprints);
        fpSHA1->setObjectName("fpSHA1");
        sizePolicy3.setHeightForWidth(fpSHA1->sizePolicy().hasHeightForWidth());
        fpSHA1->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(fpSHA1, 1, 1, 1, 1);

        TextLabel2_3 = new QLabel(fingerprints);
        TextLabel2_3->setObjectName("TextLabel2_3");
        sizePolicy2.setHeightForWidth(TextLabel2_3->sizePolicy().hasHeightForWidth());
        TextLabel2_3->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(TextLabel2_3, 2, 0, 1, 1);

        fpSHA256 = new CopyLabel(fingerprints);
        fpSHA256->setObjectName("fpSHA256");
        sizePolicy3.setHeightForWidth(fpSHA256->sizePolicy().hasHeightForWidth());
        fpSHA256->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(fpSHA256, 2, 1, 1, 1);


        verticalLayout_4->addWidget(fingerprints);

        validity = new QGroupBox(statusTab);
        validity->setObjectName("validity");
        hboxLayout1 = new QHBoxLayout(validity);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(8, 8, 8, 8);
        notBefore = new CopyLabel(validity);
        notBefore->setObjectName("notBefore");

        hboxLayout1->addWidget(notBefore);

        notAfter = new CopyLabel(validity);
        notAfter->setObjectName("notAfter");

        hboxLayout1->addWidget(notAfter);

        dateValid = new ClickLabel(validity);
        dateValid->setObjectName("dateValid");

        hboxLayout1->addWidget(dateValid);


        verticalLayout_4->addWidget(validity);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem2);

        tabwidget->addTab(statusTab, QString());
        subjectTab = new QWidget();
        subjectTab->setObjectName("subjectTab");
        vboxLayout = new QVBoxLayout(subjectTab);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        subject = new DistName(subjectTab);
        subject->setObjectName("subject");

        vboxLayout->addWidget(subject);

        tabwidget->addTab(subjectTab, QString());
        issuerTab = new QWidget();
        issuerTab->setObjectName("issuerTab");
        vboxLayout1 = new QVBoxLayout(issuerTab);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(11, 11, 11, 11);
        issuer = new DistName(issuerTab);
        issuer->setObjectName("issuer");

        vboxLayout1->addWidget(issuer);

        tabwidget->addTab(issuerTab, QString());
        attributesTab = new QWidget();
        attributesTab->setObjectName("attributesTab");
        verticalLayout_3 = new QVBoxLayout(attributesTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        attributes = new QWidget(attributesTab);
        attributes->setObjectName("attributes");

        verticalLayout_3->addWidget(attributes);

        tabwidget->addTab(attributesTab, QString());
        extensionsTab = new QWidget();
        extensionsTab->setObjectName("extensionsTab");
        verticalLayout = new QVBoxLayout(extensionsTab);
        verticalLayout->setObjectName("verticalLayout");
        v3extensions = new QTextEdit(extensionsTab);
        v3extensions->setObjectName("v3extensions");
        v3extensions->setReadOnly(true);

        verticalLayout->addWidget(v3extensions);

        showExt = new QPushButton(extensionsTab);
        showExt->setObjectName("showExt");

        verticalLayout->addWidget(showExt);

        tabwidget->addTab(extensionsTab, QString());
        validationTab = new QWidget();
        validationTab->setObjectName("validationTab");
        verticalLayout_6 = new QVBoxLayout(validationTab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        groupBox_2 = new QGroupBox(validationTab);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_10 = new QVBoxLayout(groupBox_2);
        verticalLayout_10->setObjectName("verticalLayout_10");
        purposeList = new QListWidget(groupBox_2);
        purposeList->setObjectName("purposeList");

        verticalLayout_10->addWidget(purposeList);


        verticalLayout_6->addWidget(groupBox_2);

        groupBox = new QGroupBox(validationTab);
        groupBox->setObjectName("groupBox");
        verticalLayout_11 = new QVBoxLayout(groupBox);
        verticalLayout_11->setObjectName("verticalLayout_11");
        validation = new QTextEdit(groupBox);
        validation->setObjectName("validation");

        verticalLayout_11->addWidget(validation);


        verticalLayout_6->addWidget(groupBox);

        tabwidget->addTab(validationTab, QString());
        commentTab = new QWidget();
        commentTab->setObjectName("commentTab");
        verticalLayout_5 = new QVBoxLayout(commentTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        comment = new QTextEdit(commentTab);
        comment->setObjectName("comment");
        comment->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Ubuntu'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Sans Serif'; font-size:9pt;\"><br /></p></body></html>"));
        comment->setAcceptRichText(false);

        verticalLayout_5->addWidget(comment);

        tabwidget->addTab(commentTab, QString());

        verticalLayout_2->addWidget(tabwidget);

        buttonBox = new QDialogButtonBox(CertDetail);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(CertDetail);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CertDetail, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CertDetail, qOverload<>(&QDialog::reject));

        tabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CertDetail);
    } // setupUi

    void retranslateUi(QDialog *CertDetail)
    {
        headerLabel->setText(QCoreApplication::translate("CertDetail", "Details of the Certificate", nullptr));
        TextLabel2->setText(QCoreApplication::translate("CertDetail", "Internal name", nullptr));
#if QT_CONFIG(tooltip)
        description->setToolTip(QCoreApplication::translate("CertDetail", "The internal name of the certificate in the database", nullptr));
#endif // QT_CONFIG(tooltip)
        signedLabel->setText(QCoreApplication::translate("CertDetail", "Signature", nullptr));
        signature->setText(QString());
        sigAlgo->setText(QString());
        TextLabel6->setText(QCoreApplication::translate("CertDetail", "Key", nullptr));
        privKey->setText(QString());
        serialLabel->setText(QCoreApplication::translate("CertDetail", "Serial", nullptr));
#if QT_CONFIG(tooltip)
        serialNr->setToolTip(QCoreApplication::translate("CertDetail", "The serial number of the certificate", nullptr));
#endif // QT_CONFIG(tooltip)
        serialNr->setText(QString());
        fingerprints->setTitle(QCoreApplication::translate("CertDetail", "Fingerprints", nullptr));
        TextLabel1_2->setText(QCoreApplication::translate("CertDetail", "MD5", nullptr));
#if QT_CONFIG(tooltip)
        fpMD5->setToolTip(QCoreApplication::translate("CertDetail", "An md5 hashsum of the certificate", nullptr));
#endif // QT_CONFIG(tooltip)
        TextLabel2_2->setText(QCoreApplication::translate("CertDetail", "SHA1", nullptr));
#if QT_CONFIG(tooltip)
        fpSHA1->setToolTip(QCoreApplication::translate("CertDetail", "A SHA-1 hashsum of the certificate", nullptr));
#endif // QT_CONFIG(tooltip)
        TextLabel2_3->setText(QCoreApplication::translate("CertDetail", "SHA256", nullptr));
#if QT_CONFIG(tooltip)
        fpSHA256->setToolTip(QCoreApplication::translate("CertDetail", "A SHA-256 hashsum of the certificate", nullptr));
#endif // QT_CONFIG(tooltip)
        validity->setTitle(QCoreApplication::translate("CertDetail", "Validity", nullptr));
#if QT_CONFIG(tooltip)
        notBefore->setToolTip(QCoreApplication::translate("CertDetail", "The time since the certificate is valid", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        notAfter->setToolTip(QCoreApplication::translate("CertDetail", "The time until the certificate is valid", nullptr));
#endif // QT_CONFIG(tooltip)
        dateValid->setText(QString());
        tabwidget->setTabText(tabwidget->indexOf(statusTab), QCoreApplication::translate("CertDetail", "Status", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(subjectTab), QCoreApplication::translate("CertDetail", "Subject", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(issuerTab), QCoreApplication::translate("CertDetail", "Issuer", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(attributesTab), QCoreApplication::translate("CertDetail", "Attributes", nullptr));
        showExt->setText(QCoreApplication::translate("CertDetail", "Show config", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(extensionsTab), QCoreApplication::translate("CertDetail", "Extensions", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("CertDetail", "Purposes", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CertDetail", "Strict RFC 5280 validation", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(validationTab), QCoreApplication::translate("CertDetail", "Validation", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(commentTab), QCoreApplication::translate("CertDetail", "Comment", nullptr));
        (void)CertDetail;
    } // retranslateUi

};

namespace Ui {
    class CertDetail: public Ui_CertDetail {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CERTDETAIL_H
