/********************************************************************************
** Form generated from reading UI file 'ItemProperties.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMPROPERTIES_H
#define UI_ITEMPROPERTIES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/clicklabel.h"

QT_BEGIN_NAMESPACE

class Ui_ItemProperties
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *name;
    QLabel *label_3;
    CopyLabel *source;
    QLabel *label_2;
    CopyLabel *insertionDate;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QTextEdit *comment;

    void setupUi(QWidget *ItemProperties)
    {
        if (ItemProperties->objectName().isEmpty())
            ItemProperties->setObjectName("ItemProperties");
        ItemProperties->resize(400, 295);
        verticalLayout_2 = new QVBoxLayout(ItemProperties);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ItemProperties);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        name = new QLineEdit(ItemProperties);
        name->setObjectName("name");

        gridLayout->addWidget(name, 0, 1, 1, 1);

        label_3 = new QLabel(ItemProperties);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        source = new CopyLabel(ItemProperties);
        source->setObjectName("source");

        gridLayout->addWidget(source, 1, 1, 1, 1);

        label_2 = new QLabel(ItemProperties);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        insertionDate = new CopyLabel(ItemProperties);
        insertionDate->setObjectName("insertionDate");

        gridLayout->addWidget(insertionDate, 2, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        groupBox = new QGroupBox(ItemProperties);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        comment = new QTextEdit(groupBox);
        comment->setObjectName("comment");
        comment->setAcceptRichText(false);

        verticalLayout->addWidget(comment);


        verticalLayout_2->addWidget(groupBox);


        retranslateUi(ItemProperties);

        QMetaObject::connectSlotsByName(ItemProperties);
    } // setupUi

    void retranslateUi(QWidget *ItemProperties)
    {
        ItemProperties->setWindowTitle(QString());
        label->setText(QCoreApplication::translate("ItemProperties", "Name", nullptr));
        label_3->setText(QCoreApplication::translate("ItemProperties", "Source", nullptr));
        label_2->setText(QCoreApplication::translate("ItemProperties", "Insertion date", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ItemProperties", "Comment", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ItemProperties: public Ui_ItemProperties {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMPROPERTIES_H
