/********************************************************************************
** Form generated from reading UI file 'ExportDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXPORTDIALOG_H
#define UI_EXPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include "widgets/FocusCombo.h"

QT_BEGIN_NAMESPACE

class Ui_ExportDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QSpacerItem *spacerItem;
    QLabel *image;
    QGridLayout *gridLayout;
    QLabel *descriptionLabel;
    QLineEdit *description;
    QLabel *filenameLabel;
    QLineEdit *filename;
    QToolButton *fileBut;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *separateFiles;
    QCheckBox *samePassword;
    QCheckBox *pemComment;
    QHBoxLayout *horizontalLayout;
    focusCombo *exportFormat;
    QLabel *infoBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ExportDialog)
    {
        if (ExportDialog->objectName().isEmpty())
            ExportDialog->setObjectName("ExportDialog");
        ExportDialog->resize(671, 385);
        verticalLayout_2 = new QVBoxLayout(ExportDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label = new QLabel(ExportDialog);
        label->setObjectName("label");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        label->setFont(font);

        hboxLayout->addWidget(label);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(ExportDialog);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout_2->addLayout(hboxLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        descriptionLabel = new QLabel(ExportDialog);
        descriptionLabel->setObjectName("descriptionLabel");

        gridLayout->addWidget(descriptionLabel, 0, 0, 1, 1);

        description = new QLineEdit(ExportDialog);
        description->setObjectName("description");

        gridLayout->addWidget(description, 0, 1, 1, 1);

        filenameLabel = new QLabel(ExportDialog);
        filenameLabel->setObjectName("filenameLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(filenameLabel->sizePolicy().hasHeightForWidth());
        filenameLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(filenameLabel, 1, 0, 1, 1);

        filename = new QLineEdit(ExportDialog);
        filename->setObjectName("filename");

        gridLayout->addWidget(filename, 1, 1, 1, 1);

        fileBut = new QToolButton(ExportDialog);
        fileBut->setObjectName("fileBut");
        sizePolicy.setHeightForWidth(fileBut->sizePolicy().hasHeightForWidth());
        fileBut->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fileBut, 1, 2, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        groupBox = new QGroupBox(ExportDialog);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        separateFiles = new QCheckBox(groupBox);
        separateFiles->setObjectName("separateFiles");

        verticalLayout->addWidget(separateFiles);

        samePassword = new QCheckBox(groupBox);
        samePassword->setObjectName("samePassword");

        verticalLayout->addWidget(samePassword);

        pemComment = new QCheckBox(groupBox);
        pemComment->setObjectName("pemComment");

        verticalLayout->addWidget(pemComment);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        exportFormat = new focusCombo(groupBox);
        exportFormat->setObjectName("exportFormat");

        horizontalLayout->addWidget(exportFormat);

        infoBox = new QLabel(groupBox);
        infoBox->setObjectName("infoBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(infoBox->sizePolicy().hasHeightForWidth());
        infoBox->setSizePolicy(sizePolicy1);
        infoBox->setMinimumSize(QSize(0, 100));
        infoBox->setFrameShape(QFrame::Box);
        infoBox->setFrameShadow(QFrame::Sunken);
        infoBox->setText(QString::fromUtf8(""));
        infoBox->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        infoBox->setWordWrap(true);

        horizontalLayout->addWidget(infoBox);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(ExportDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(ExportDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ExportDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ExportDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ExportDialog);
    } // setupUi

    void retranslateUi(QDialog *ExportDialog)
    {
        ExportDialog->setWindowTitle(QString());
        descriptionLabel->setText(QCoreApplication::translate("ExportDialog", "Name", nullptr));
#if QT_CONFIG(tooltip)
        description->setToolTip(QCoreApplication::translate("ExportDialog", "The internal name of the CRL in the database", nullptr));
#endif // QT_CONFIG(tooltip)
        filenameLabel->setText(QCoreApplication::translate("ExportDialog", "Filename", nullptr));
        fileBut->setText(QCoreApplication::translate("ExportDialog", "...", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ExportDialog", "Export Format", nullptr));
        separateFiles->setText(QCoreApplication::translate("ExportDialog", "Each Item in a separate file", nullptr));
        samePassword->setText(QCoreApplication::translate("ExportDialog", "Same encryption password for all items", nullptr));
        pemComment->setText(QCoreApplication::translate("ExportDialog", "Export comment into PEM file", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ExportDialog: public Ui_ExportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EXPORTDIALOG_H
