/********************************************************************************
** Form generated from reading UI file 'NewX509.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWX509_H
#define UI_NEWX509_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/ItemCombo.h"
#include "widgets/clicklabel.h"
#include "widgets/hashBox.h"
#include "widgets/kvView.h"
#include "widgets/validity.h"

QT_BEGIN_NAMESPACE

class Ui_NewX509
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *_4;
    QLabel *capt;
    QSpacerItem *spacerItem;
    QLabel *image;
    QTabWidget *tabWidget;
    QWidget *tab_0;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *spacerItem1;
    QGroupBox *requestBox;
    QVBoxLayout *vboxLayout;
    QWidget *reqWidget;
    QGridLayout *gridLayout1;
    itemComboReq *reqList;
    QPushButton *showReqBut;
    QCheckBox *fromReqCB;
    QCheckBox *copyReqExtCB;
    QCheckBox *reqSubChange;
    QWidget *attrWidget;
    QSpacerItem *spacerItem2;
    QGroupBox *signerBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QRadioButton *selfSignRB;
    QHBoxLayout *hboxLayout1;
    QRadioButton *foreignSignRB;
    itemComboCert *certList;
    QSpacerItem *spacerItem3;
    QHBoxLayout *hboxLayout2;
    QLabel *label;
    hashBox *hashAlgo;
    QSpacerItem *spacerItem4;
    QGroupBox *templBox;
    QVBoxLayout *verticalLayout_3;
    itemComboTemp *tempList;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *applyExtensions;
    QPushButton *applySubject;
    QPushButton *applyTemplate;
    QSpacerItem *spacerItem5;
    QWidget *tab_1;
    QVBoxLayout *verticalLayout_7;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_2;
    QLineEdit *description;
    QGroupBox *distNameBox;
    QVBoxLayout *verticalLayout_6;
    QWidget *dnWidget;
    QHBoxLayout *horizontalLayout_3;
    kvView *extDNlist;
    QVBoxLayout *verticalLayout_5;
    QPushButton *extDNadd;
    QPushButton *extDNdel;
    QSpacerItem *verticalSpacer;
    QLabel *extDNinfo;
    QGroupBox *privKeyBox;
    QHBoxLayout *horizontalLayout_7;
    itemComboKey *keyList;
    QCheckBox *usedKeysToo;
    QPushButton *genKeyBut;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *_6;
    QGroupBox *bcBox;
    QGridLayout *gridLayout_7;
    QLabel *TextLabel2_2_3;
    QComboBox *basicCA;
    QLabel *TextLabel3_2_2;
    QLineEdit *basicPath;
    QCheckBox *bcCritical;
    QGroupBox *keyIdentBox;
    QVBoxLayout *vboxLayout2;
    QCheckBox *subKey;
    QCheckBox *authKey;
    QSpacerItem *spacerItem6;
    QWidget *timewidget;
    QHBoxLayout *horizontalLayout;
    QGroupBox *validityBox;
    QGridLayout *gridLayout_1;
    QLabel *TextLabel1_2_3_2;
    Validity *notBefore;
    QLabel *TextLabel2_4_2;
    Validity *notAfter;
    QGroupBox *rangeBox;
    QGridLayout *gridLayout_2;
    QLineEdit *validN;
    QComboBox *validRange;
    QCheckBox *checkBox;
    QCheckBox *noWellDefinedExpDate;
    QPushButton *applyTime;
    QCheckBox *validMidn;
    QSpacerItem *spacerItem7;
    QGridLayout *gridLayout;
    QCheckBox *OCSPstaple;
    QLabel *subAltIco;
    QLineEdit *subAltName;
    QPushButton *editNameCons;
    QLabel *nameConsIco;
    QPushButton *editSubAlt;
    DoubleClickLabel *nameConsLbl;
    QLineEdit *nameCons;
    DoubleClickLabel *sanLbl;
    DoubleClickLabel *ianLbl;
    DoubleClickLabel *crldpLbl;
    QPushButton *editIssAlt;
    QLineEdit *issAltName;
    QLabel *issAltIco;
    DoubleClickLabel *aiaLbl;
    QLineEdit *authInfAcc;
    QPushButton *editAuthInfAcc;
    QLabel *crlDistIco;
    QPushButton *editCrlDist;
    QLabel *authInfAccIco;
    QLineEdit *crlDist;
    QWidget *tab_3;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout3;
    QGroupBox *kuBox;
    QVBoxLayout *vboxLayout4;
    QCheckBox *kuCritical;
    QListWidget *keyUsage;
    QGroupBox *ekuBox;
    QVBoxLayout *vboxLayout5;
    QCheckBox *ekuCritical;
    QListWidget *ekeyUsage;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *horizontalLayout_5;
    QGroupBox *nsCertTypeBox;
    QHBoxLayout *horizontalLayout_4;
    QListWidget *nsCertType;
    QSpacerItem *spacerItem8;
    QVBoxLayout *vboxLayout6;
    QLabel *nsImg;
    QSpacerItem *spacerItem9;
    QGridLayout *gridLayout_3;
    QLineEdit *nsRenewalUrl;
    QLineEdit *nsCaPolicyUrl;
    DoubleClickLabel *nsCaRevLbl;
    QLineEdit *nsSslServerName;
    DoubleClickLabel *nsRevLbl;
    DoubleClickLabel *nsSslServerLbl;
    QLineEdit *nsBaseUrl;
    QLineEdit *nsCARevocationUrl;
    DoubleClickLabel *nsRenewLbl;
    DoubleClickLabel *nsCommentLbl;
    DoubleClickLabel *nsCaPolicyLbl;
    DoubleClickLabel *nsBaseLbl;
    QLineEdit *nsRevocationUrl;
    QLineEdit *nsComment;
    QWidget *Seite;
    QVBoxLayout *vboxLayout7;
    QTextEdit *nconf_data;
    QHBoxLayout *hboxLayout4;
    QSpacerItem *spacerItem10;
    QPushButton *adv_validate;
    QSpacerItem *spacerItem11;
    QWidget *tab;
    QVBoxLayout *verticalLayout_9;
    QTextEdit *comment;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NewX509)
    {
        if (NewX509->objectName().isEmpty())
            NewX509->setObjectName("NewX509");
        NewX509->resize(747, 640);
        verticalLayout_2 = new QVBoxLayout(NewX509);
        verticalLayout_2->setObjectName("verticalLayout_2");
        _4 = new QHBoxLayout();
        _4->setObjectName("_4");
        capt = new QLabel(NewX509);
        capt->setObjectName("capt");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        capt->setFont(font);

        _4->addWidget(capt);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _4->addItem(spacerItem);

        image = new QLabel(NewX509);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        _4->addWidget(image);


        verticalLayout_2->addLayout(_4);

        tabWidget = new QTabWidget(NewX509);
        tabWidget->setObjectName("tabWidget");
        tab_0 = new QWidget();
        tab_0->setObjectName("tab_0");
        verticalLayout_4 = new QVBoxLayout(tab_0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        spacerItem1 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem1);

        requestBox = new QGroupBox(tab_0);
        requestBox->setObjectName("requestBox");
        vboxLayout = new QVBoxLayout(requestBox);
        vboxLayout->setObjectName("vboxLayout");
        reqWidget = new QWidget(requestBox);
        reqWidget->setObjectName("reqWidget");
        gridLayout1 = new QGridLayout(reqWidget);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        reqList = new itemComboReq(reqWidget);
        reqList->setObjectName("reqList");

        gridLayout1->addWidget(reqList, 0, 1, 1, 1);

        showReqBut = new QPushButton(reqWidget);
        showReqBut->setObjectName("showReqBut");

        gridLayout1->addWidget(showReqBut, 1, 1, 1, 1);

        fromReqCB = new QCheckBox(reqWidget);
        fromReqCB->setObjectName("fromReqCB");

        gridLayout1->addWidget(fromReqCB, 0, 0, 1, 1);

        copyReqExtCB = new QCheckBox(reqWidget);
        copyReqExtCB->setObjectName("copyReqExtCB");
        copyReqExtCB->setChecked(true);

        gridLayout1->addWidget(copyReqExtCB, 1, 0, 1, 1);

        reqSubChange = new QCheckBox(reqWidget);
        reqSubChange->setObjectName("reqSubChange");

        gridLayout1->addWidget(reqSubChange, 2, 0, 1, 1);


        vboxLayout->addWidget(reqWidget);

        attrWidget = new QWidget(requestBox);
        attrWidget->setObjectName("attrWidget");

        vboxLayout->addWidget(attrWidget);


        verticalLayout_4->addWidget(requestBox);

        spacerItem2 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem2);

        signerBox = new QGroupBox(tab_0);
        signerBox->setObjectName("signerBox");
        vboxLayout1 = new QVBoxLayout(signerBox);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        selfSignRB = new QRadioButton(signerBox);
        selfSignRB->setObjectName("selfSignRB");
        selfSignRB->setChecked(true);

        hboxLayout->addWidget(selfSignRB);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        foreignSignRB = new QRadioButton(signerBox);
        foreignSignRB->setObjectName("foreignSignRB");

        hboxLayout1->addWidget(foreignSignRB);

        certList = new itemComboCert(signerBox);
        certList->setObjectName("certList");

        hboxLayout1->addWidget(certList);


        vboxLayout1->addLayout(hboxLayout1);


        verticalLayout_4->addWidget(signerBox);

        spacerItem3 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem3);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        label = new QLabel(tab_0);
        label->setObjectName("label");

        hboxLayout2->addWidget(label);

        hashAlgo = new hashBox(tab_0);
        hashAlgo->setObjectName("hashAlgo");

        hboxLayout2->addWidget(hashAlgo);


        verticalLayout_4->addLayout(hboxLayout2);

        spacerItem4 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem4);

        templBox = new QGroupBox(tab_0);
        templBox->setObjectName("templBox");
        verticalLayout_3 = new QVBoxLayout(templBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        tempList = new itemComboTemp(templBox);
        tempList->setObjectName("tempList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tempList->sizePolicy().hasHeightForWidth());
        tempList->setSizePolicy(sizePolicy);

        verticalLayout_3->addWidget(tempList);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(13, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        applyExtensions = new QPushButton(templBox);
        applyExtensions->setObjectName("applyExtensions");

        horizontalLayout_2->addWidget(applyExtensions);

        applySubject = new QPushButton(templBox);
        applySubject->setObjectName("applySubject");

        horizontalLayout_2->addWidget(applySubject);

        applyTemplate = new QPushButton(templBox);
        applyTemplate->setObjectName("applyTemplate");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(applyTemplate->sizePolicy().hasHeightForWidth());
        applyTemplate->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(applyTemplate);


        verticalLayout_3->addLayout(horizontalLayout_2);


        verticalLayout_4->addWidget(templBox);

        spacerItem5 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem5);

        tabWidget->addTab(tab_0, QString());
        tab_1 = new QWidget();
        tab_1->setObjectName("tab_1");
        verticalLayout_7 = new QVBoxLayout(tab_1);
        verticalLayout_7->setObjectName("verticalLayout_7");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_2 = new QLabel(tab_1);
        label_2->setObjectName("label_2");

        horizontalLayout_6->addWidget(label_2);

        description = new QLineEdit(tab_1);
        description->setObjectName("description");

        horizontalLayout_6->addWidget(description);


        verticalLayout_7->addLayout(horizontalLayout_6);

        distNameBox = new QGroupBox(tab_1);
        distNameBox->setObjectName("distNameBox");
        distNameBox->setTitle(QString::fromUtf8("Distinguished name"));
        verticalLayout_6 = new QVBoxLayout(distNameBox);
        verticalLayout_6->setObjectName("verticalLayout_6");
        dnWidget = new QWidget(distNameBox);
        dnWidget->setObjectName("dnWidget");

        verticalLayout_6->addWidget(dnWidget);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        extDNlist = new kvView(distNameBox);
        extDNlist->setObjectName("extDNlist");
        extDNlist->horizontalHeader()->setDefaultSectionSize(200);
        extDNlist->horizontalHeader()->setStretchLastSection(true);

        horizontalLayout_3->addWidget(extDNlist);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        extDNadd = new QPushButton(distNameBox);
        extDNadd->setObjectName("extDNadd");

        verticalLayout_5->addWidget(extDNadd);

        extDNdel = new QPushButton(distNameBox);
        extDNdel->setObjectName("extDNdel");

        verticalLayout_5->addWidget(extDNdel);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);


        horizontalLayout_3->addLayout(verticalLayout_5);


        verticalLayout_6->addLayout(horizontalLayout_3);

        extDNinfo = new QLabel(distNameBox);
        extDNinfo->setObjectName("extDNinfo");
        extDNinfo->setFrameShape(QFrame::Panel);
        extDNinfo->setFrameShadow(QFrame::Sunken);

        verticalLayout_6->addWidget(extDNinfo);


        verticalLayout_7->addWidget(distNameBox);

        privKeyBox = new QGroupBox(tab_1);
        privKeyBox->setObjectName("privKeyBox");
        horizontalLayout_7 = new QHBoxLayout(privKeyBox);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        keyList = new itemComboKey(privKeyBox);
        keyList->setObjectName("keyList");
        sizePolicy.setHeightForWidth(keyList->sizePolicy().hasHeightForWidth());
        keyList->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(keyList);

        usedKeysToo = new QCheckBox(privKeyBox);
        usedKeysToo->setObjectName("usedKeysToo");

        horizontalLayout_7->addWidget(usedKeysToo);

        genKeyBut = new QPushButton(privKeyBox);
        genKeyBut->setObjectName("genKeyBut");

        horizontalLayout_7->addWidget(genKeyBut);


        verticalLayout_7->addWidget(privKeyBox);

        tabWidget->addTab(tab_1, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout = new QVBoxLayout(tab_2);
        verticalLayout->setObjectName("verticalLayout");
        _6 = new QHBoxLayout();
        _6->setObjectName("_6");
        bcBox = new QGroupBox(tab_2);
        bcBox->setObjectName("bcBox");
        gridLayout_7 = new QGridLayout(bcBox);
        gridLayout_7->setObjectName("gridLayout_7");
        TextLabel2_2_3 = new QLabel(bcBox);
        TextLabel2_2_3->setObjectName("TextLabel2_2_3");

        gridLayout_7->addWidget(TextLabel2_2_3, 0, 0, 1, 1);

        basicCA = new QComboBox(bcBox);
        basicCA->addItem(QString());
        basicCA->addItem(QString());
        basicCA->addItem(QString());
        basicCA->setObjectName("basicCA");

        gridLayout_7->addWidget(basicCA, 0, 1, 1, 1);

        TextLabel3_2_2 = new QLabel(bcBox);
        TextLabel3_2_2->setObjectName("TextLabel3_2_2");

        gridLayout_7->addWidget(TextLabel3_2_2, 1, 0, 1, 1);

        basicPath = new QLineEdit(bcBox);
        basicPath->setObjectName("basicPath");

        gridLayout_7->addWidget(basicPath, 1, 1, 1, 1);

        bcCritical = new QCheckBox(bcBox);
        bcCritical->setObjectName("bcCritical");
        bcCritical->setText(QString::fromUtf8("Critical"));

        gridLayout_7->addWidget(bcCritical, 1, 2, 1, 1);


        _6->addWidget(bcBox);

        keyIdentBox = new QGroupBox(tab_2);
        keyIdentBox->setObjectName("keyIdentBox");
        keyIdentBox->setTitle(QString::fromUtf8("Key identifier"));
        vboxLayout2 = new QVBoxLayout(keyIdentBox);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        subKey = new QCheckBox(keyIdentBox);
        subKey->setObjectName("subKey");
        subKey->setText(QString::fromUtf8("&Subject Key Identifier"));

        vboxLayout2->addWidget(subKey);

        authKey = new QCheckBox(keyIdentBox);
        authKey->setObjectName("authKey");
        authKey->setText(QString::fromUtf8("&Authority Key Identifier"));

        vboxLayout2->addWidget(authKey);


        _6->addWidget(keyIdentBox);


        verticalLayout->addLayout(_6);

        spacerItem6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem6);

        timewidget = new QWidget(tab_2);
        timewidget->setObjectName("timewidget");
        timewidget->setEnabled(true);
        horizontalLayout = new QHBoxLayout(timewidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        validityBox = new QGroupBox(timewidget);
        validityBox->setObjectName("validityBox");
        gridLayout_1 = new QGridLayout(validityBox);
        gridLayout_1->setObjectName("gridLayout_1");
        TextLabel1_2_3_2 = new QLabel(validityBox);
        TextLabel1_2_3_2->setObjectName("TextLabel1_2_3_2");

        gridLayout_1->addWidget(TextLabel1_2_3_2, 0, 0, 1, 1);

        notBefore = new Validity(validityBox);
        notBefore->setObjectName("notBefore");
        notBefore->setCalendarPopup(true);

        gridLayout_1->addWidget(notBefore, 0, 1, 1, 1);

        TextLabel2_4_2 = new QLabel(validityBox);
        TextLabel2_4_2->setObjectName("TextLabel2_4_2");

        gridLayout_1->addWidget(TextLabel2_4_2, 1, 0, 1, 1);

        notAfter = new Validity(validityBox);
        notAfter->setObjectName("notAfter");
        notAfter->setCalendarPopup(true);

        gridLayout_1->addWidget(notAfter, 1, 1, 1, 1);


        horizontalLayout->addWidget(validityBox);

        rangeBox = new QGroupBox(timewidget);
        rangeBox->setObjectName("rangeBox");
        gridLayout_2 = new QGridLayout(rangeBox);
        gridLayout_2->setObjectName("gridLayout_2");
        validN = new QLineEdit(rangeBox);
        validN->setObjectName("validN");

        gridLayout_2->addWidget(validN, 0, 0, 1, 2);

        validRange = new QComboBox(rangeBox);
        validRange->addItem(QString());
        validRange->addItem(QString());
        validRange->addItem(QString());
        validRange->setObjectName("validRange");

        gridLayout_2->addWidget(validRange, 0, 2, 1, 1);

        checkBox = new QCheckBox(rangeBox);
        checkBox->setObjectName("checkBox");

        gridLayout_2->addWidget(checkBox, 1, 1, 1, 1);

        noWellDefinedExpDate = new QCheckBox(rangeBox);
        noWellDefinedExpDate->setObjectName("noWellDefinedExpDate");

        gridLayout_2->addWidget(noWellDefinedExpDate, 1, 2, 1, 2);

        applyTime = new QPushButton(rangeBox);
        applyTime->setObjectName("applyTime");
        sizePolicy1.setHeightForWidth(applyTime->sizePolicy().hasHeightForWidth());
        applyTime->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(applyTime, 0, 3, 1, 1);

        validMidn = new QCheckBox(rangeBox);
        validMidn->setObjectName("validMidn");

        gridLayout_2->addWidget(validMidn, 1, 0, 1, 1);


        horizontalLayout->addWidget(rangeBox);


        verticalLayout->addWidget(timewidget);

        spacerItem7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem7);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        OCSPstaple = new QCheckBox(tab_2);
        OCSPstaple->setObjectName("OCSPstaple");
        OCSPstaple->setText(QString::fromUtf8("OCSP Must Staple"));

        gridLayout->addWidget(OCSPstaple, 5, 2, 1, 2);

        subAltIco = new QLabel(tab_2);
        subAltIco->setObjectName("subAltIco");
        subAltIco->setMinimumSize(QSize(20, 20));
        subAltIco->setMaximumSize(QSize(20, 20));

        gridLayout->addWidget(subAltIco, 1, 1, 1, 1);

        subAltName = new QLineEdit(tab_2);
        subAltName->setObjectName("subAltName");

        gridLayout->addWidget(subAltName, 1, 2, 1, 1);

        editNameCons = new QPushButton(tab_2);
        editNameCons->setObjectName("editNameCons");

        gridLayout->addWidget(editNameCons, 0, 3, 1, 1);

        nameConsIco = new QLabel(tab_2);
        nameConsIco->setObjectName("nameConsIco");
        nameConsIco->setMinimumSize(QSize(20, 20));
        nameConsIco->setMaximumSize(QSize(20, 20));

        gridLayout->addWidget(nameConsIco, 0, 1, 1, 1);

        editSubAlt = new QPushButton(tab_2);
        editSubAlt->setObjectName("editSubAlt");

        gridLayout->addWidget(editSubAlt, 1, 3, 1, 1);

        nameConsLbl = new DoubleClickLabel(tab_2);
        nameConsLbl->setObjectName("nameConsLbl");

        gridLayout->addWidget(nameConsLbl, 0, 0, 1, 1);

        nameCons = new QLineEdit(tab_2);
        nameCons->setObjectName("nameCons");

        gridLayout->addWidget(nameCons, 0, 2, 1, 1);

        sanLbl = new DoubleClickLabel(tab_2);
        sanLbl->setObjectName("sanLbl");

        gridLayout->addWidget(sanLbl, 1, 0, 1, 1);

        ianLbl = new DoubleClickLabel(tab_2);
        ianLbl->setObjectName("ianLbl");

        gridLayout->addWidget(ianLbl, 2, 0, 1, 1);

        crldpLbl = new DoubleClickLabel(tab_2);
        crldpLbl->setObjectName("crldpLbl");

        gridLayout->addWidget(crldpLbl, 3, 0, 1, 1);

        editIssAlt = new QPushButton(tab_2);
        editIssAlt->setObjectName("editIssAlt");

        gridLayout->addWidget(editIssAlt, 2, 3, 1, 1);

        issAltName = new QLineEdit(tab_2);
        issAltName->setObjectName("issAltName");

        gridLayout->addWidget(issAltName, 2, 2, 1, 1);

        issAltIco = new QLabel(tab_2);
        issAltIco->setObjectName("issAltIco");
        issAltIco->setMinimumSize(QSize(20, 20));
        issAltIco->setMaximumSize(QSize(20, 20));

        gridLayout->addWidget(issAltIco, 2, 1, 1, 1);

        aiaLbl = new DoubleClickLabel(tab_2);
        aiaLbl->setObjectName("aiaLbl");

        gridLayout->addWidget(aiaLbl, 4, 0, 1, 1);

        authInfAcc = new QLineEdit(tab_2);
        authInfAcc->setObjectName("authInfAcc");

        gridLayout->addWidget(authInfAcc, 4, 2, 1, 1);

        editAuthInfAcc = new QPushButton(tab_2);
        editAuthInfAcc->setObjectName("editAuthInfAcc");

        gridLayout->addWidget(editAuthInfAcc, 4, 3, 1, 1);

        crlDistIco = new QLabel(tab_2);
        crlDistIco->setObjectName("crlDistIco");
        crlDistIco->setMinimumSize(QSize(20, 20));
        crlDistIco->setMaximumSize(QSize(20, 20));

        gridLayout->addWidget(crlDistIco, 3, 1, 1, 1);

        editCrlDist = new QPushButton(tab_2);
        editCrlDist->setObjectName("editCrlDist");

        gridLayout->addWidget(editCrlDist, 3, 3, 1, 1);

        authInfAccIco = new QLabel(tab_2);
        authInfAccIco->setObjectName("authInfAccIco");
        authInfAccIco->setMinimumSize(QSize(20, 20));
        authInfAccIco->setMaximumSize(QSize(20, 20));

        gridLayout->addWidget(authInfAccIco, 4, 1, 1, 1);

        crlDist = new QLineEdit(tab_2);
        crlDist->setObjectName("crlDist");

        gridLayout->addWidget(crlDist, 3, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        vboxLayout3 = new QVBoxLayout(tab_3);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(8, 8, 8, 8);
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        kuBox = new QGroupBox(tab_3);
        kuBox->setObjectName("kuBox");
        vboxLayout4 = new QVBoxLayout(kuBox);
        vboxLayout4->setObjectName("vboxLayout4");
        vboxLayout4->setContentsMargins(8, 8, 8, 8);
        kuCritical = new QCheckBox(kuBox);
        kuCritical->setObjectName("kuCritical");
        kuCritical->setText(QString::fromUtf8("Critical"));

        vboxLayout4->addWidget(kuCritical);

        keyUsage = new QListWidget(kuBox);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(keyUsage);
        __qlistwidgetitem->setText(QString::fromUtf8("Digital Signature"));
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem1->setText(QString::fromUtf8("Non Repudiation"));
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem2->setText(QString::fromUtf8("Key Encipherment"));
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem3->setText(QString::fromUtf8("Data Encipherment"));
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem4->setText(QString::fromUtf8("Key Agreement"));
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem5->setText(QString::fromUtf8("Certificate Sign"));
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem6->setText(QString::fromUtf8("CRL Sign"));
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem7->setText(QString::fromUtf8("Encipher Only"));
        QListWidgetItem *__qlistwidgetitem8 = new QListWidgetItem(keyUsage);
        __qlistwidgetitem8->setText(QString::fromUtf8("Decipher Only"));
        keyUsage->setObjectName("keyUsage");
        keyUsage->setSelectionMode(QAbstractItemView::MultiSelection);
        keyUsage->setSelectionBehavior(QAbstractItemView::SelectRows);

        vboxLayout4->addWidget(keyUsage);


        hboxLayout3->addWidget(kuBox);

        ekuBox = new QGroupBox(tab_3);
        ekuBox->setObjectName("ekuBox");
        vboxLayout5 = new QVBoxLayout(ekuBox);
        vboxLayout5->setObjectName("vboxLayout5");
        vboxLayout5->setContentsMargins(8, 8, 8, 8);
        ekuCritical = new QCheckBox(ekuBox);
        ekuCritical->setObjectName("ekuCritical");
        ekuCritical->setText(QString::fromUtf8("Critical"));

        vboxLayout5->addWidget(ekuCritical);

        ekeyUsage = new QListWidget(ekuBox);
        ekeyUsage->setObjectName("ekeyUsage");
        ekeyUsage->setSelectionMode(QAbstractItemView::MultiSelection);
        ekeyUsage->setSelectionBehavior(QAbstractItemView::SelectRows);

        vboxLayout5->addWidget(ekeyUsage);


        hboxLayout3->addWidget(ekuBox);


        vboxLayout3->addLayout(hboxLayout3);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout_8 = new QVBoxLayout(tab_4);
        verticalLayout_8->setObjectName("verticalLayout_8");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        nsCertTypeBox = new QGroupBox(tab_4);
        nsCertTypeBox->setObjectName("nsCertTypeBox");
        horizontalLayout_4 = new QHBoxLayout(nsCertTypeBox);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        nsCertType = new QListWidget(nsCertTypeBox);
        QListWidgetItem *__qlistwidgetitem9 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem9->setText(QString::fromUtf8("SSL Client"));
        QListWidgetItem *__qlistwidgetitem10 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem10->setText(QString::fromUtf8("SSL Server"));
        QListWidgetItem *__qlistwidgetitem11 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem11->setText(QString::fromUtf8("S/MIME"));
        QListWidgetItem *__qlistwidgetitem12 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem12->setText(QString::fromUtf8("Object Signing"));
        QListWidgetItem *__qlistwidgetitem13 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem13->setText(QString::fromUtf8("SSL CA"));
        QListWidgetItem *__qlistwidgetitem14 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem14->setText(QString::fromUtf8("S/MIME CA"));
        QListWidgetItem *__qlistwidgetitem15 = new QListWidgetItem(nsCertType);
        __qlistwidgetitem15->setText(QString::fromUtf8("Object Signing CA"));
        nsCertType->setObjectName("nsCertType");
        nsCertType->setSelectionMode(QAbstractItemView::MultiSelection);

        horizontalLayout_4->addWidget(nsCertType);


        horizontalLayout_5->addWidget(nsCertTypeBox);

        spacerItem8 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(spacerItem8);

        vboxLayout6 = new QVBoxLayout();
        vboxLayout6->setObjectName("vboxLayout6");
        nsImg = new QLabel(tab_4);
        nsImg->setObjectName("nsImg");
        nsImg->setMinimumSize(QSize(107, 107));
        nsImg->setScaledContents(true);

        vboxLayout6->addWidget(nsImg);

        spacerItem9 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout6->addItem(spacerItem9);


        horizontalLayout_5->addLayout(vboxLayout6);


        verticalLayout_8->addLayout(horizontalLayout_5);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        nsRenewalUrl = new QLineEdit(tab_4);
        nsRenewalUrl->setObjectName("nsRenewalUrl");

        gridLayout_3->addWidget(nsRenewalUrl, 3, 1, 1, 1);

        nsCaPolicyUrl = new QLineEdit(tab_4);
        nsCaPolicyUrl->setObjectName("nsCaPolicyUrl");

        gridLayout_3->addWidget(nsCaPolicyUrl, 4, 1, 1, 1);

        nsCaRevLbl = new DoubleClickLabel(tab_4);
        nsCaRevLbl->setObjectName("nsCaRevLbl");

        gridLayout_3->addWidget(nsCaRevLbl, 2, 0, 1, 1);

        nsSslServerName = new QLineEdit(tab_4);
        nsSslServerName->setObjectName("nsSslServerName");

        gridLayout_3->addWidget(nsSslServerName, 5, 1, 1, 1);

        nsRevLbl = new DoubleClickLabel(tab_4);
        nsRevLbl->setObjectName("nsRevLbl");

        gridLayout_3->addWidget(nsRevLbl, 1, 0, 1, 1);

        nsSslServerLbl = new DoubleClickLabel(tab_4);
        nsSslServerLbl->setObjectName("nsSslServerLbl");

        gridLayout_3->addWidget(nsSslServerLbl, 5, 0, 1, 1);

        nsBaseUrl = new QLineEdit(tab_4);
        nsBaseUrl->setObjectName("nsBaseUrl");

        gridLayout_3->addWidget(nsBaseUrl, 0, 1, 1, 1);

        nsCARevocationUrl = new QLineEdit(tab_4);
        nsCARevocationUrl->setObjectName("nsCARevocationUrl");

        gridLayout_3->addWidget(nsCARevocationUrl, 2, 1, 1, 1);

        nsRenewLbl = new DoubleClickLabel(tab_4);
        nsRenewLbl->setObjectName("nsRenewLbl");

        gridLayout_3->addWidget(nsRenewLbl, 3, 0, 1, 1);

        nsCommentLbl = new DoubleClickLabel(tab_4);
        nsCommentLbl->setObjectName("nsCommentLbl");

        gridLayout_3->addWidget(nsCommentLbl, 6, 0, 1, 1);

        nsCaPolicyLbl = new DoubleClickLabel(tab_4);
        nsCaPolicyLbl->setObjectName("nsCaPolicyLbl");

        gridLayout_3->addWidget(nsCaPolicyLbl, 4, 0, 1, 1);

        nsBaseLbl = new DoubleClickLabel(tab_4);
        nsBaseLbl->setObjectName("nsBaseLbl");

        gridLayout_3->addWidget(nsBaseLbl, 0, 0, 1, 1);

        nsRevocationUrl = new QLineEdit(tab_4);
        nsRevocationUrl->setObjectName("nsRevocationUrl");

        gridLayout_3->addWidget(nsRevocationUrl, 1, 1, 1, 1);

        nsComment = new QLineEdit(tab_4);
        nsComment->setObjectName("nsComment");
#if QT_CONFIG(tooltip)
        nsComment->setToolTip(QString::fromUtf8("If you know a more pretty one tell me"));
#endif // QT_CONFIG(tooltip)

        gridLayout_3->addWidget(nsComment, 6, 1, 1, 1);


        verticalLayout_8->addLayout(gridLayout_3);

        tabWidget->addTab(tab_4, QString());
        Seite = new QWidget();
        Seite->setObjectName("Seite");
        vboxLayout7 = new QVBoxLayout(Seite);
        vboxLayout7->setObjectName("vboxLayout7");
        nconf_data = new QTextEdit(Seite);
        nconf_data->setObjectName("nconf_data");

        vboxLayout7->addWidget(nconf_data);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        spacerItem10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem10);

        adv_validate = new QPushButton(Seite);
        adv_validate->setObjectName("adv_validate");

        hboxLayout4->addWidget(adv_validate);

        spacerItem11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem11);


        vboxLayout7->addLayout(hboxLayout4);

        tabWidget->addTab(Seite, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_9 = new QVBoxLayout(tab);
        verticalLayout_9->setObjectName("verticalLayout_9");
        comment = new QTextEdit(tab);
        comment->setObjectName("comment");

        verticalLayout_9->addWidget(comment);

        tabWidget->addTab(tab, QString());

        verticalLayout_2->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(NewX509);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);

        QWidget::setTabOrder(fromReqCB, reqList);
        QWidget::setTabOrder(reqList, copyReqExtCB);
        QWidget::setTabOrder(copyReqExtCB, showReqBut);
        QWidget::setTabOrder(showReqBut, reqSubChange);
        QWidget::setTabOrder(reqSubChange, selfSignRB);
        QWidget::setTabOrder(selfSignRB, foreignSignRB);
        QWidget::setTabOrder(foreignSignRB, certList);
        QWidget::setTabOrder(certList, hashAlgo);
        QWidget::setTabOrder(hashAlgo, tempList);
        QWidget::setTabOrder(tempList, applyExtensions);
        QWidget::setTabOrder(applyExtensions, applySubject);
        QWidget::setTabOrder(applySubject, applyTemplate);
        QWidget::setTabOrder(applyTemplate, extDNlist);
        QWidget::setTabOrder(extDNlist, extDNadd);
        QWidget::setTabOrder(extDNadd, extDNdel);
        QWidget::setTabOrder(extDNdel, keyList);
        QWidget::setTabOrder(keyList, usedKeysToo);
        QWidget::setTabOrder(usedKeysToo, genKeyBut);
        QWidget::setTabOrder(genKeyBut, basicCA);
        QWidget::setTabOrder(basicCA, basicPath);
        QWidget::setTabOrder(basicPath, bcCritical);
        QWidget::setTabOrder(bcCritical, subKey);
        QWidget::setTabOrder(subKey, authKey);
        QWidget::setTabOrder(authKey, notBefore);
        QWidget::setTabOrder(notBefore, notAfter);
        QWidget::setTabOrder(notAfter, validN);
        QWidget::setTabOrder(validN, validMidn);
        QWidget::setTabOrder(validMidn, checkBox);
        QWidget::setTabOrder(checkBox, noWellDefinedExpDate);
        QWidget::setTabOrder(noWellDefinedExpDate, validRange);
        QWidget::setTabOrder(validRange, applyTime);
        QWidget::setTabOrder(applyTime, subAltName);
        QWidget::setTabOrder(subAltName, editSubAlt);
        QWidget::setTabOrder(editSubAlt, issAltName);
        QWidget::setTabOrder(issAltName, editIssAlt);
        QWidget::setTabOrder(editIssAlt, crlDist);
        QWidget::setTabOrder(crlDist, editCrlDist);
        QWidget::setTabOrder(editCrlDist, authInfAcc);
        QWidget::setTabOrder(authInfAcc, editAuthInfAcc);
        QWidget::setTabOrder(editAuthInfAcc, kuCritical);
        QWidget::setTabOrder(kuCritical, keyUsage);
        QWidget::setTabOrder(keyUsage, ekuCritical);
        QWidget::setTabOrder(ekuCritical, ekeyUsage);
        QWidget::setTabOrder(ekeyUsage, nsCertType);
        QWidget::setTabOrder(nsCertType, nsBaseUrl);
        QWidget::setTabOrder(nsBaseUrl, nsRevocationUrl);
        QWidget::setTabOrder(nsRevocationUrl, nsCARevocationUrl);
        QWidget::setTabOrder(nsCARevocationUrl, nsRenewalUrl);
        QWidget::setTabOrder(nsRenewalUrl, nsCaPolicyUrl);
        QWidget::setTabOrder(nsCaPolicyUrl, nsSslServerName);
        QWidget::setTabOrder(nsSslServerName, nsComment);
        QWidget::setTabOrder(nsComment, nconf_data);
        QWidget::setTabOrder(nconf_data, adv_validate);
        QWidget::setTabOrder(adv_validate, buttonBox);
        QWidget::setTabOrder(buttonBox, tabWidget);

        retranslateUi(NewX509);
        QObject::connect(noWellDefinedExpDate, SIGNAL(clicked(bool)), notAfter, SLOT(setDisabled(bool)));
        QObject::connect(fromReqCB, SIGNAL(clicked(bool)), reqList, SLOT(setEnabled(bool)));
        QObject::connect(extDNdel, &QPushButton::clicked, extDNlist, qOverload<>(&kvView::deleteCurrentRow));
        QObject::connect(extDNadd, &QPushButton::clicked, extDNlist, qOverload<>(&kvView::addKvRow));
        QObject::connect(foreignSignRB, SIGNAL(toggled(bool)), certList, SLOT(setEnabled(bool)));
        QObject::connect(validMidn, SIGNAL(stateChanged(int)), notBefore, SLOT(hideTimeCheck(int)));
        QObject::connect(validMidn, SIGNAL(stateChanged(int)), notAfter, SLOT(hideTimeCheck(int)));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NewX509, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NewX509, qOverload<>(&QDialog::reject));
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), notAfter, SLOT(localTime(int)));
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), notBefore, SLOT(localTime(int)));
        QObject::connect(validMidn, &QCheckBox::clicked, checkBox, &QCheckBox::setDisabled);
        QObject::connect(selfSignRB, &QRadioButton::toggled, authKey, &QCheckBox::setDisabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(NewX509);
    } // setupUi

    void retranslateUi(QDialog *NewX509)
    {
        requestBox->setTitle(QCoreApplication::translate("NewX509", "Signing request", nullptr));
        showReqBut->setText(QCoreApplication::translate("NewX509", "Show request", nullptr));
        fromReqCB->setText(QCoreApplication::translate("NewX509", "Sign this Certificate signing &request", nullptr));
        copyReqExtCB->setText(QCoreApplication::translate("NewX509", "Copy extensions from the request", nullptr));
        reqSubChange->setText(QCoreApplication::translate("NewX509", "Modify subject of the request", nullptr));
        signerBox->setTitle(QCoreApplication::translate("NewX509", "Signing", nullptr));
        selfSignRB->setText(QCoreApplication::translate("NewX509", "Create a &self signed certificate", nullptr));
        foreignSignRB->setText(QCoreApplication::translate("NewX509", "Use &this Certificate for signing", nullptr));
#if QT_CONFIG(tooltip)
        certList->setToolTip(QCoreApplication::translate("NewX509", "All certificates in your database that can create valid signatures", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("NewX509", "Signature algorithm", nullptr));
        templBox->setTitle(QCoreApplication::translate("NewX509", "Template for the new certificate", nullptr));
#if QT_CONFIG(tooltip)
        tempList->setToolTip(QCoreApplication::translate("NewX509", "All available templates", nullptr));
#endif // QT_CONFIG(tooltip)
        applyExtensions->setText(QCoreApplication::translate("NewX509", "Apply extensions", nullptr));
        applySubject->setText(QCoreApplication::translate("NewX509", "Apply subject", nullptr));
        applyTemplate->setText(QCoreApplication::translate("NewX509", "Apply all", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_0), QCoreApplication::translate("NewX509", "Source", nullptr));
        label_2->setText(QCoreApplication::translate("NewX509", "Internal Name", nullptr));
#if QT_CONFIG(tooltip)
        description->setToolTip(QCoreApplication::translate("NewX509", "This name is only used internally and does not appear in the resulting certificate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        distNameBox->setToolTip(QCoreApplication::translate("NewX509", "Distinguished name", nullptr));
#endif // QT_CONFIG(tooltip)
        extDNadd->setText(QCoreApplication::translate("NewX509", "Add", nullptr));
        extDNdel->setText(QCoreApplication::translate("NewX509", "Delete", nullptr));
        privKeyBox->setTitle(QCoreApplication::translate("NewX509", "Private key", nullptr));
#if QT_CONFIG(tooltip)
        keyList->setToolTip(QCoreApplication::translate("NewX509", "This list only contains unused keys", nullptr));
#endif // QT_CONFIG(tooltip)
        usedKeysToo->setText(QCoreApplication::translate("NewX509", "Used keys too", nullptr));
        genKeyBut->setText(QCoreApplication::translate("NewX509", "&Generate a new key", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_1), QCoreApplication::translate("NewX509", "Subject", nullptr));
        TextLabel2_2_3->setText(QCoreApplication::translate("NewX509", "Type", nullptr));
        basicCA->setItemText(0, QCoreApplication::translate("NewX509", "Not defined", nullptr));
        basicCA->setItemText(1, QCoreApplication::translate("NewX509", "Certification Authority", nullptr));
        basicCA->setItemText(2, QCoreApplication::translate("NewX509", "End Entity", nullptr));

#if QT_CONFIG(tooltip)
        basicCA->setToolTip(QCoreApplication::translate("NewX509", "If this will become a CA certificate or not", nullptr));
#endif // QT_CONFIG(tooltip)
        TextLabel3_2_2->setText(QCoreApplication::translate("NewX509", "Path length", nullptr));
#if QT_CONFIG(tooltip)
        basicPath->setToolTip(QCoreApplication::translate("NewX509", "How much CAs may be below this.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        bcCritical->setToolTip(QCoreApplication::translate("NewX509", "The basic constraints should always be critical", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        keyIdentBox->setToolTip(QCoreApplication::translate("NewX509", "Key identifier", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        subKey->setToolTip(QCoreApplication::translate("NewX509", "Creates a hash of the key following the PKIX guidelines", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        authKey->setToolTip(QCoreApplication::translate("NewX509", "Copy the Subject Key Identifier from the issuer", nullptr));
#endif // QT_CONFIG(tooltip)
        validityBox->setTitle(QCoreApplication::translate("NewX509", "Validity", nullptr));
        TextLabel1_2_3_2->setText(QCoreApplication::translate("NewX509", "Not before", nullptr));
        TextLabel2_4_2->setText(QCoreApplication::translate("NewX509", "Not after", nullptr));
        rangeBox->setTitle(QCoreApplication::translate("NewX509", "Time range", nullptr));
        validRange->setItemText(0, QCoreApplication::translate("NewX509", "Days", nullptr));
        validRange->setItemText(1, QCoreApplication::translate("NewX509", "Months", nullptr));
        validRange->setItemText(2, QCoreApplication::translate("NewX509", "Years", nullptr));

        checkBox->setText(QCoreApplication::translate("NewX509", "Local time", nullptr));
        noWellDefinedExpDate->setText(QCoreApplication::translate("NewX509", "No well-defined expiration", nullptr));
        applyTime->setText(QCoreApplication::translate("NewX509", "Apply", nullptr));
#if QT_CONFIG(tooltip)
        validMidn->setToolTip(QCoreApplication::translate("NewX509", "Set the time to 00:00:00 and 23:59:59 respectively", nullptr));
#endif // QT_CONFIG(tooltip)
        validMidn->setText(QCoreApplication::translate("NewX509", "Midnight", nullptr));
        subAltIco->setText(QString());
#if QT_CONFIG(tooltip)
        subAltName->setToolTip(QCoreApplication::translate("NewX509", "DNS: IP: URI: email: RID:", nullptr));
#endif // QT_CONFIG(tooltip)
        editNameCons->setText(QCoreApplication::translate("NewX509", "Edit", nullptr));
        nameConsIco->setText(QString());
        editSubAlt->setText(QCoreApplication::translate("NewX509", "Edit", nullptr));
#if QT_CONFIG(tooltip)
        nameCons->setToolTip(QCoreApplication::translate("NewX509", "DNS: IP: URI: email: RID:", nullptr));
#endif // QT_CONFIG(tooltip)
        editIssAlt->setText(QCoreApplication::translate("NewX509", "Edit", nullptr));
#if QT_CONFIG(tooltip)
        issAltName->setToolTip(QCoreApplication::translate("NewX509", "DNS: IP: URI: email: RID:", nullptr));
#endif // QT_CONFIG(tooltip)
        issAltIco->setText(QString());
#if QT_CONFIG(tooltip)
        authInfAcc->setToolTip(QCoreApplication::translate("NewX509", "DNS: IP: URI: email: RID:", nullptr));
#endif // QT_CONFIG(tooltip)
        editAuthInfAcc->setText(QCoreApplication::translate("NewX509", "Edit", nullptr));
        crlDistIco->setText(QString());
        editCrlDist->setText(QCoreApplication::translate("NewX509", "Edit", nullptr));
        authInfAccIco->setText(QString());
#if QT_CONFIG(tooltip)
        crlDist->setToolTip(QCoreApplication::translate("NewX509", "URI:", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("NewX509", "Extensions", nullptr));

        const bool __sortingEnabled = keyUsage->isSortingEnabled();
        keyUsage->setSortingEnabled(false);
        keyUsage->setSortingEnabled(__sortingEnabled);

        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("NewX509", "Key usage", nullptr));

        const bool __sortingEnabled1 = nsCertType->isSortingEnabled();
        nsCertType->setSortingEnabled(false);
        nsCertType->setSortingEnabled(__sortingEnabled1);

        tabWidget->setTabText(tabWidget->indexOf(tab_4), QCoreApplication::translate("NewX509", "Netscape", nullptr));
        adv_validate->setText(QCoreApplication::translate("NewX509", "Validate", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Seite), QCoreApplication::translate("NewX509", "Advanced", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("NewX509", "Comment", nullptr));
        (void)NewX509;
    } // retranslateUi

};

namespace Ui {
    class NewX509: public Ui_NewX509 {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NEWX509_H
