/********************************************************************************
** Form generated from reading UI file 'Revoke.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REVOKE_H
#define UI_REVOKE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "widgets/validity.h"

QT_BEGIN_NAMESPACE

class Ui_Revoke
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *capt;
    QSpacerItem *spacerItem;
    QLabel *image;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLineEdit *serial;
    QLabel *label_2;
    Validity *invalid;
    QCheckBox *checkBox;
    QLabel *label;
    QLabel *label_3;
    QComboBox *reason;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Revoke)
    {
        if (Revoke->objectName().isEmpty())
            Revoke->setObjectName("Revoke");
        Revoke->resize(417, 282);
        verticalLayout = new QVBoxLayout(Revoke);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        capt = new QLabel(Revoke);
        capt->setObjectName("capt");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        capt->setFont(font);

        horizontalLayout->addWidget(capt);

        spacerItem = new QSpacerItem(78, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem);

        image = new QLabel(Revoke);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        horizontalLayout->addWidget(image);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        groupBox = new QGroupBox(Revoke);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        serial = new QLineEdit(groupBox);
        serial->setObjectName("serial");

        gridLayout->addWidget(serial, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        invalid = new Validity(groupBox);
        invalid->setObjectName("invalid");
        invalid->setCalendarPopup(true);

        gridLayout->addWidget(invalid, 1, 1, 1, 1);

        checkBox = new QCheckBox(groupBox);
        checkBox->setObjectName("checkBox");

        gridLayout->addWidget(checkBox, 2, 1, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        reason = new QComboBox(groupBox);
        reason->setObjectName("reason");

        gridLayout->addWidget(reason, 3, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(Revoke);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(Revoke);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, Revoke, qOverload<>(&QDialog::accept));
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), invalid, SLOT(localTime(int)));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, Revoke, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(Revoke);
    } // setupUi

    void retranslateUi(QDialog *Revoke)
    {
        capt->setText(QCoreApplication::translate("Revoke", "Certificate revocation", nullptr));
        groupBox->setTitle(QCoreApplication::translate("Revoke", "Revocation details", nullptr));
        label_2->setText(QCoreApplication::translate("Revoke", "Revocation reason", nullptr));
        checkBox->setText(QCoreApplication::translate("Revoke", "Local time", nullptr));
        label->setText(QCoreApplication::translate("Revoke", "Invalid since", nullptr));
        label_3->setText(QCoreApplication::translate("Revoke", "Serial", nullptr));
        (void)Revoke;
    } // retranslateUi

};

namespace Ui {
    class Revoke: public Ui_Revoke {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_REVOKE_H
