/********************************************************************************
** Form generated from reading UI file 'KeyDetail.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYDETAIL_H
#define UI_KEYDETAIL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/clicklabel.h"

QT_BEGIN_NAMESPACE

class Ui_KeyDetail
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *hboxLayout;
    QLabel *tlHeader;
    QSpacerItem *spacerItem;
    QLabel *image;
    QHBoxLayout *horizontalLayout_3;
    QLabel *TextLabel1;
    QLineEdit *description;
    QTabWidget *tabWidget;
    QWidget *key;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *tlPubEx;
    CopyLabel *keyPubEx;
    QSpacerItem *spacerItem1;
    QLabel *TextLabel3;
    CopyLabel *keyLength;
    QHBoxLayout *horizontalLayout_2;
    QLabel *tlPrivEx;
    ClickLabel *keyPrivEx;
    QGroupBox *tlModulus;
    QVBoxLayout *verticalLayout;
    QTextBrowser *keyModulus;
    QWidget *token;
    QVBoxLayout *verticalLayout_5;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout;
    QLabel *label_5;
    CopyLabel *slotLabel;
    QLabel *label_6;
    CopyLabel *cardId;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    CopyLabel *cardModel;
    QLabel *label;
    CopyLabel *cardManufacturer;
    QLabel *label_2;
    CopyLabel *cardSerial;
    QLabel *label_4;
    CopyLabel *cardLabel;
    QWidget *fingerprint;
    QWidget *commenttab;
    QVBoxLayout *verticalLayout_3;
    QTextEdit *comment;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *KeyDetail)
    {
        if (KeyDetail->objectName().isEmpty())
            KeyDetail->setObjectName("KeyDetail");
        KeyDetail->resize(572, 403);
        verticalLayout_4 = new QVBoxLayout(KeyDetail);
        verticalLayout_4->setObjectName("verticalLayout_4");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        tlHeader = new QLabel(KeyDetail);
        tlHeader->setObjectName("tlHeader");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        tlHeader->setFont(font);

        hboxLayout->addWidget(tlHeader);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(KeyDetail);
        image->setObjectName("image");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(image->sizePolicy().hasHeightForWidth());
        image->setSizePolicy(sizePolicy);
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout_4->addLayout(hboxLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        TextLabel1 = new QLabel(KeyDetail);
        TextLabel1->setObjectName("TextLabel1");

        horizontalLayout_3->addWidget(TextLabel1);

        description = new QLineEdit(KeyDetail);
        description->setObjectName("description");

        horizontalLayout_3->addWidget(description);


        verticalLayout_4->addLayout(horizontalLayout_3);

        tabWidget = new QTabWidget(KeyDetail);
        tabWidget->setObjectName("tabWidget");
        key = new QWidget();
        key->setObjectName("key");
        verticalLayout_2 = new QVBoxLayout(key);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        tlPubEx = new QLabel(key);
        tlPubEx->setObjectName("tlPubEx");

        horizontalLayout->addWidget(tlPubEx);

        keyPubEx = new CopyLabel(key);
        keyPubEx->setObjectName("keyPubEx");

        horizontalLayout->addWidget(keyPubEx);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem1);

        TextLabel3 = new QLabel(key);
        TextLabel3->setObjectName("TextLabel3");

        horizontalLayout->addWidget(TextLabel3);

        keyLength = new CopyLabel(key);
        keyLength->setObjectName("keyLength");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(keyLength->sizePolicy().hasHeightForWidth());
        keyLength->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(keyLength);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        tlPrivEx = new QLabel(key);
        tlPrivEx->setObjectName("tlPrivEx");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tlPrivEx->sizePolicy().hasHeightForWidth());
        tlPrivEx->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(tlPrivEx);

        keyPrivEx = new ClickLabel(key);
        keyPrivEx->setObjectName("keyPrivEx");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Ignored);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(keyPrivEx->sizePolicy().hasHeightForWidth());
        keyPrivEx->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(keyPrivEx);


        verticalLayout_2->addLayout(horizontalLayout_2);

        tlModulus = new QGroupBox(key);
        tlModulus->setObjectName("tlModulus");
        verticalLayout = new QVBoxLayout(tlModulus);
        verticalLayout->setObjectName("verticalLayout");
        keyModulus = new QTextBrowser(tlModulus);
        keyModulus->setObjectName("keyModulus");
        keyModulus->setFrameShape(QFrame::NoFrame);
        keyModulus->setFrameShadow(QFrame::Sunken);
        keyModulus->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        keyModulus->setAcceptRichText(false);
        keyModulus->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);
        keyModulus->setOpenLinks(false);

        verticalLayout->addWidget(keyModulus);


        verticalLayout_2->addWidget(tlModulus);

        tabWidget->addTab(key, QString());
        token = new QWidget();
        token->setObjectName("token");
        verticalLayout_5 = new QVBoxLayout(token);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalSpacer_2 = new QSpacerItem(20, 33, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_5 = new QLabel(token);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 0, 0, 1, 1);

        slotLabel = new CopyLabel(token);
        slotLabel->setObjectName("slotLabel");

        gridLayout->addWidget(slotLabel, 0, 1, 1, 1);

        label_6 = new QLabel(token);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 1, 0, 1, 1);

        cardId = new CopyLabel(token);
        cardId->setObjectName("cardId");

        gridLayout->addWidget(cardId, 1, 1, 1, 1);


        verticalLayout_5->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 32, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);

        groupBox = new QGroupBox(token);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        cardModel = new CopyLabel(groupBox);
        cardModel->setObjectName("cardModel");

        gridLayout_2->addWidget(cardModel, 0, 1, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        cardManufacturer = new CopyLabel(groupBox);
        cardManufacturer->setObjectName("cardManufacturer");

        gridLayout_2->addWidget(cardManufacturer, 1, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 2, 0, 1, 1);

        cardSerial = new CopyLabel(groupBox);
        cardSerial->setObjectName("cardSerial");

        gridLayout_2->addWidget(cardSerial, 2, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 3, 0, 1, 1);

        cardLabel = new CopyLabel(groupBox);
        cardLabel->setObjectName("cardLabel");

        gridLayout_2->addWidget(cardLabel, 3, 1, 1, 1);


        verticalLayout_5->addWidget(groupBox);

        tabWidget->addTab(token, QString());
        fingerprint = new QWidget();
        fingerprint->setObjectName("fingerprint");
        tabWidget->addTab(fingerprint, QString());
        commenttab = new QWidget();
        commenttab->setObjectName("commenttab");
        verticalLayout_3 = new QVBoxLayout(commenttab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        comment = new QTextEdit(commenttab);
        comment->setObjectName("comment");
        comment->setAcceptDrops(false);
        comment->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Ubuntu'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Sans Serif'; font-size:9pt;\"><br /></p></body></html>"));

        verticalLayout_3->addWidget(comment);

        tabWidget->addTab(commenttab, QString());

        verticalLayout_4->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(KeyDetail);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_4->addWidget(buttonBox);


        retranslateUi(KeyDetail);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, KeyDetail, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, KeyDetail, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KeyDetail);
    } // setupUi

    void retranslateUi(QDialog *KeyDetail)
    {
        tlHeader->setText(QString());
        TextLabel1->setText(QCoreApplication::translate("KeyDetail", "Name", nullptr));
#if QT_CONFIG(tooltip)
        description->setToolTip(QCoreApplication::translate("KeyDetail", "The internal name of the key used by xca", nullptr));
#endif // QT_CONFIG(tooltip)
        tlPubEx->setText(QCoreApplication::translate("KeyDetail", "Public Exponent", nullptr));
        TextLabel3->setText(QCoreApplication::translate("KeyDetail", "Keysize", nullptr));
        tlPrivEx->setText(QCoreApplication::translate("KeyDetail", "Private Exponent", nullptr));
        tlModulus->setTitle(QCoreApplication::translate("KeyDetail", "Key", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(key), QCoreApplication::translate("KeyDetail", "Key", nullptr));
        label_5->setText(QCoreApplication::translate("KeyDetail", "Label", nullptr));
        label_6->setText(QCoreApplication::translate("KeyDetail", "PKCS#11 ID", nullptr));
        groupBox->setTitle(QCoreApplication::translate("KeyDetail", "Token information", nullptr));
        label_3->setText(QCoreApplication::translate("KeyDetail", "Model", nullptr));
        label->setText(QCoreApplication::translate("KeyDetail", "Manufacturer", nullptr));
        label_2->setText(QCoreApplication::translate("KeyDetail", "Serial", nullptr));
        label_4->setText(QCoreApplication::translate("KeyDetail", "Label", nullptr));
        cardLabel->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(token), QCoreApplication::translate("KeyDetail", "Security Token", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(fingerprint), QCoreApplication::translate("KeyDetail", "Fingerprint", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(commenttab), QCoreApplication::translate("KeyDetail", "Comment", nullptr));
        (void)KeyDetail;
    } // retranslateUi

};

namespace Ui {
    class KeyDetail: public Ui_KeyDetail {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KEYDETAIL_H
