/********************************************************************************
** Form generated from reading UI file 'CertExtend.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CERTEXTEND_H
#define UI_CERTEXTEND_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "widgets/validity.h"

QT_BEGIN_NAMESPACE

class Ui_CertExtend
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *capt;
    QSpacerItem *spacerItem;
    QLabel *image;
    QLabel *TextLabel1;
    QSpacerItem *spacerItem1;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *TextLabel1_2;
    QLabel *TextLabel2_4;
    Validity *notBefore;
    Validity *notAfter;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_1;
    QCheckBox *checkBox;
    QComboBox *validRange;
    QCheckBox *noWellDefinedExpDate;
    QCheckBox *midnightCB;
    QPushButton *applyTime;
    QLineEdit *validNumber;
    QSpacerItem *verticalSpacer;
    QCheckBox *revoke;
    QCheckBox *replace;
    QCheckBox *keepSerial;
    QSpacerItem *spacerItem2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CertExtend)
    {
        if (CertExtend->objectName().isEmpty())
            CertExtend->setObjectName("CertExtend");
        CertExtend->resize(411, 416);
        verticalLayout = new QVBoxLayout(CertExtend);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        capt = new QLabel(CertExtend);
        capt->setObjectName("capt");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        capt->setFont(font);

        horizontalLayout->addWidget(capt);

        spacerItem = new QSpacerItem(78, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem);

        image = new QLabel(CertExtend);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        horizontalLayout->addWidget(image);


        verticalLayout->addLayout(horizontalLayout);

        TextLabel1 = new QLabel(CertExtend);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setWordWrap(true);

        verticalLayout->addWidget(TextLabel1);

        spacerItem1 = new QSpacerItem(368, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem1);

        groupBox_2 = new QGroupBox(CertExtend);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout = new QVBoxLayout(groupBox_2);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        TextLabel1_2 = new QLabel(groupBox_2);
        TextLabel1_2->setObjectName("TextLabel1_2");

        gridLayout->addWidget(TextLabel1_2, 0, 0, 1, 1);

        TextLabel2_4 = new QLabel(groupBox_2);
        TextLabel2_4->setObjectName("TextLabel2_4");

        gridLayout->addWidget(TextLabel2_4, 1, 0, 1, 1);

        notBefore = new Validity(groupBox_2);
        notBefore->setObjectName("notBefore");
        notBefore->setCalendarPopup(true);

        gridLayout->addWidget(notBefore, 0, 1, 1, 1);

        notAfter = new Validity(groupBox_2);
        notAfter->setObjectName("notAfter");
        notAfter->setCalendarPopup(true);

        gridLayout->addWidget(notAfter, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);


        verticalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(CertExtend);
        groupBox->setObjectName("groupBox");
        gridLayout_1 = new QGridLayout(groupBox);
        gridLayout_1->setSpacing(6);
        gridLayout_1->setContentsMargins(9, 9, 9, 9);
        gridLayout_1->setObjectName("gridLayout_1");
        checkBox = new QCheckBox(groupBox);
        checkBox->setObjectName("checkBox");

        gridLayout_1->addWidget(checkBox, 1, 1, 1, 1);

        validRange = new QComboBox(groupBox);
        validRange->addItem(QString());
        validRange->addItem(QString());
        validRange->addItem(QString());
        validRange->setObjectName("validRange");

        gridLayout_1->addWidget(validRange, 0, 2, 1, 1);

        noWellDefinedExpDate = new QCheckBox(groupBox);
        noWellDefinedExpDate->setObjectName("noWellDefinedExpDate");

        gridLayout_1->addWidget(noWellDefinedExpDate, 1, 2, 1, 2);

        midnightCB = new QCheckBox(groupBox);
        midnightCB->setObjectName("midnightCB");

        gridLayout_1->addWidget(midnightCB, 1, 0, 1, 1);

        applyTime = new QPushButton(groupBox);
        applyTime->setObjectName("applyTime");

        gridLayout_1->addWidget(applyTime, 0, 3, 1, 1);

        validNumber = new QLineEdit(groupBox);
        validNumber->setObjectName("validNumber");

        gridLayout_1->addWidget(validNumber, 0, 0, 1, 2);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 2, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        revoke = new QCheckBox(CertExtend);
        revoke->setObjectName("revoke");
        revoke->setChecked(false);

        verticalLayout->addWidget(revoke);

        replace = new QCheckBox(CertExtend);
        replace->setObjectName("replace");
        replace->setChecked(true);

        verticalLayout->addWidget(replace);

        keepSerial = new QCheckBox(CertExtend);
        keepSerial->setObjectName("keepSerial");

        verticalLayout->addWidget(keepSerial);

        spacerItem2 = new QSpacerItem(368, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem2);

        buttonBox = new QDialogButtonBox(CertExtend);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(validNumber, validRange);
        QWidget::setTabOrder(validRange, midnightCB);
        QWidget::setTabOrder(midnightCB, applyTime);

        retranslateUi(CertExtend);
        QObject::connect(midnightCB, SIGNAL(stateChanged(int)), notAfter, SLOT(hideTimeCheck(int)));
        QObject::connect(noWellDefinedExpDate, SIGNAL(clicked(bool)), notAfter, SLOT(setDisabled(bool)));
        QObject::connect(midnightCB, SIGNAL(stateChanged(int)), notBefore, SLOT(hideTimeCheck(int)));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CertExtend, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CertExtend, qOverload<>(&QDialog::reject));
        QObject::connect(midnightCB, &QCheckBox::clicked, checkBox, &QCheckBox::setDisabled);
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), notBefore, SLOT(localTime(int)));
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), notAfter, SLOT(localTime(int)));

        QMetaObject::connectSlotsByName(CertExtend);
    } // setupUi

    void retranslateUi(QDialog *CertExtend)
    {
        capt->setText(QCoreApplication::translate("CertExtend", "Certificate renewal", nullptr));
        TextLabel1->setText(QCoreApplication::translate("CertExtend", "This will create a new certificate as a copy of the old one with a new serial number and adjusted validity values.", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("CertExtend", "Validity", nullptr));
        TextLabel1_2->setText(QCoreApplication::translate("CertExtend", "Not before", nullptr));
        TextLabel2_4->setText(QCoreApplication::translate("CertExtend", "Not after", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CertExtend", "Time range", nullptr));
        checkBox->setText(QCoreApplication::translate("CertExtend", "Local time", nullptr));
        validRange->setItemText(0, QCoreApplication::translate("CertExtend", "Days", nullptr));
        validRange->setItemText(1, QCoreApplication::translate("CertExtend", "Months", nullptr));
        validRange->setItemText(2, QCoreApplication::translate("CertExtend", "Years", nullptr));

        noWellDefinedExpDate->setText(QCoreApplication::translate("CertExtend", "No well-defined expiration", nullptr));
        midnightCB->setText(QCoreApplication::translate("CertExtend", "Midnight", nullptr));
        applyTime->setText(QCoreApplication::translate("CertExtend", "Apply", nullptr));
        revoke->setText(QCoreApplication::translate("CertExtend", "Revoke old certificate", nullptr));
        replace->setText(QCoreApplication::translate("CertExtend", "Replace old certificate", nullptr));
        keepSerial->setText(QCoreApplication::translate("CertExtend", "Keep serial number", nullptr));
        (void)CertExtend;
    } // retranslateUi

};

namespace Ui {
    class CertExtend: public Ui_CertExtend {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CERTEXTEND_H
