/********************************************************************************
** Form generated from reading UI file 'CaProperties.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPROPERTIES_H
#define UI_CAPROPERTIES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "widgets/ItemCombo.h"

QT_BEGIN_NAMESPACE

class Ui_CaProperties
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *days;
    QLabel *label_2;
    itemComboTemp *temp;

    void setupUi(QWidget *Form)
    {
        if (Form->objectName().isEmpty())
            Form->setObjectName("Form");
        Form->resize(405, 97);
        gridLayout = new QGridLayout(Form);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(Form);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        days = new QSpinBox(Form);
        days->setObjectName("days");

        gridLayout->addWidget(days, 0, 1, 1, 1);

        label_2 = new QLabel(Form);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        temp = new itemComboTemp(Form);
        temp->setObjectName("temp");

        gridLayout->addWidget(temp, 1, 1, 1, 1);


        retranslateUi(Form);

        QMetaObject::connectSlotsByName(Form);
    } // setupUi

    void retranslateUi(QWidget *Form)
    {
        Form->setWindowTitle(QCoreApplication::translate("CaProperties", "Form", nullptr));
        label->setText(QCoreApplication::translate("CaProperties", "Days until next CRL issuing", nullptr));
        label_2->setText(QCoreApplication::translate("CaProperties", "Default template", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CaProperties: public Ui_CaProperties {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CAPROPERTIES_H
