/********************************************************************************
** Form generated from reading UI file 'CrlDetail.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CRLDETAIL_H
#define UI_CRLDETAIL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/clicklabel.h"
#include "widgets/distname.h"

QT_BEGIN_NAMESPACE

class Ui_CrlDetail
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QLabel *TextLabel1;
    QSpacerItem *spacerItem;
    QLabel *image;
    QTabWidget *tabview;
    QWidget *unnamed;
    QVBoxLayout *vboxLayout;
    QSpacerItem *spacerItem1;
    QFrame *frame;
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout1;
    ClickLabel *signCheck;
    QLabel *TextLabel1_3;
    CopyLabel *version;
    QLabel *TextLabel6;
    QLabel *TextLabel4;
    QLabel *TextLabel2;
    QLineEdit *description;
    ClickLabel *issuerIntName;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QLabel *TextLabel2_2;
    QLabel *TextLabel1_2;
    CopyLabel *nUpdate;
    CopyLabel *lUpdate;
    QSpacerItem *spacerItem2;
    QWidget *Widget9;
    QVBoxLayout *vboxLayout1;
    DistName *issuer;
    QWidget *unnamed_1;
    QVBoxLayout *vboxLayout2;
    QTextEdit *v3extensions;
    QWidget *tab;
    QVBoxLayout *vboxLayout3;
    QTreeWidget *certList;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_2;
    QTextEdit *comment;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CrlDetail)
    {
        if (CrlDetail->objectName().isEmpty())
            CrlDetail->setObjectName("CrlDetail");
        CrlDetail->resize(530, 381);
        verticalLayout = new QVBoxLayout(CrlDetail);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        TextLabel1 = new QLabel(CrlDetail);
        TextLabel1->setObjectName("TextLabel1");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        TextLabel1->setFont(font);

        hboxLayout->addWidget(TextLabel1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(CrlDetail);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout->addLayout(hboxLayout);

        tabview = new QTabWidget(CrlDetail);
        tabview->setObjectName("tabview");
        unnamed = new QWidget();
        unnamed->setObjectName("unnamed");
        vboxLayout = new QVBoxLayout(unnamed);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);

        frame = new QFrame(unnamed);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Box);
        frame->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        signCheck = new ClickLabel(frame);
        signCheck->setObjectName("signCheck");

        hboxLayout1->addWidget(signCheck);

        TextLabel1_3 = new QLabel(frame);
        TextLabel1_3->setObjectName("TextLabel1_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TextLabel1_3->sizePolicy().hasHeightForWidth());
        TextLabel1_3->setSizePolicy(sizePolicy);

        hboxLayout1->addWidget(TextLabel1_3);

        version = new CopyLabel(frame);
        version->setObjectName("version");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(version->sizePolicy().hasHeightForWidth());
        version->setSizePolicy(sizePolicy1);

        hboxLayout1->addWidget(version);


        gridLayout->addLayout(hboxLayout1, 2, 1, 1, 1);

        TextLabel6 = new QLabel(frame);
        TextLabel6->setObjectName("TextLabel6");

        gridLayout->addWidget(TextLabel6, 2, 0, 1, 1);

        TextLabel4 = new QLabel(frame);
        TextLabel4->setObjectName("TextLabel4");

        gridLayout->addWidget(TextLabel4, 1, 0, 1, 1);

        TextLabel2 = new QLabel(frame);
        TextLabel2->setObjectName("TextLabel2");

        gridLayout->addWidget(TextLabel2, 0, 0, 1, 1);

        description = new QLineEdit(frame);
        description->setObjectName("description");

        gridLayout->addWidget(description, 0, 1, 1, 1);

        issuerIntName = new ClickLabel(frame);
        issuerIntName->setObjectName("issuerIntName");

        gridLayout->addWidget(issuerIntName, 1, 1, 1, 1);


        vboxLayout->addWidget(frame);

        groupBox = new QGroupBox(unnamed);
        groupBox->setObjectName("groupBox");
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        TextLabel2_2 = new QLabel(groupBox);
        TextLabel2_2->setObjectName("TextLabel2_2");

        gridLayout1->addWidget(TextLabel2_2, 1, 0, 1, 1);

        TextLabel1_2 = new QLabel(groupBox);
        TextLabel1_2->setObjectName("TextLabel1_2");

        gridLayout1->addWidget(TextLabel1_2, 0, 0, 1, 1);

        nUpdate = new CopyLabel(groupBox);
        nUpdate->setObjectName("nUpdate");

        gridLayout1->addWidget(nUpdate, 1, 1, 1, 1);

        lUpdate = new CopyLabel(groupBox);
        lUpdate->setObjectName("lUpdate");

        gridLayout1->addWidget(lUpdate, 0, 1, 1, 1);


        vboxLayout->addWidget(groupBox);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);

        tabview->addTab(unnamed, QString());
        Widget9 = new QWidget();
        Widget9->setObjectName("Widget9");
        vboxLayout1 = new QVBoxLayout(Widget9);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(11, 11, 11, 11);
        issuer = new DistName(Widget9);
        issuer->setObjectName("issuer");

        vboxLayout1->addWidget(issuer);

        tabview->addTab(Widget9, QString());
        unnamed_1 = new QWidget();
        unnamed_1->setObjectName("unnamed_1");
        vboxLayout2 = new QVBoxLayout(unnamed_1);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(11, 11, 11, 11);
        v3extensions = new QTextEdit(unnamed_1);
        v3extensions->setObjectName("v3extensions");
        v3extensions->setAcceptDrops(false);
        v3extensions->setReadOnly(true);

        vboxLayout2->addWidget(v3extensions);

        tabview->addTab(unnamed_1, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout3 = new QVBoxLayout(tab);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(11, 11, 11, 11);
        certList = new QTreeWidget(tab);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        certList->setHeaderItem(__qtreewidgetitem);
        certList->setObjectName("certList");
        certList->setAlternatingRowColors(true);
        certList->setSelectionMode(QAbstractItemView::NoSelection);

        vboxLayout3->addWidget(certList);

        tabview->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_2 = new QVBoxLayout(tab_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        comment = new QTextEdit(tab_2);
        comment->setObjectName("comment");
        comment->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Cantarell'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Sans Serif'; font-size:9pt;\"><br /></p></body></html>"));
        comment->setAcceptRichText(false);

        verticalLayout_2->addWidget(comment);

        tabview->addTab(tab_2, QString());

        verticalLayout->addWidget(tabview);

        buttonBox = new QDialogButtonBox(CrlDetail);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CrlDetail);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CrlDetail, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CrlDetail, qOverload<>(&QDialog::reject));

        tabview->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CrlDetail);
    } // setupUi

    void retranslateUi(QDialog *CrlDetail)
    {
        TextLabel1->setText(QCoreApplication::translate("CrlDetail", "Details of the Revocation list", nullptr));
        TextLabel1_3->setText(QCoreApplication::translate("CrlDetail", "Version", nullptr));
        TextLabel6->setText(QCoreApplication::translate("CrlDetail", "Signature", nullptr));
        TextLabel4->setText(QCoreApplication::translate("CrlDetail", "Signed by", nullptr));
        TextLabel2->setText(QCoreApplication::translate("CrlDetail", "Name", nullptr));
#if QT_CONFIG(tooltip)
        description->setToolTip(QCoreApplication::translate("CrlDetail", "The internal name of the CRL in the database", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(QCoreApplication::translate("CrlDetail", "issuing dates", nullptr));
        TextLabel2_2->setText(QCoreApplication::translate("CrlDetail", "Next update", nullptr));
        TextLabel1_2->setText(QCoreApplication::translate("CrlDetail", "Last update", nullptr));
        tabview->setTabText(tabview->indexOf(unnamed), QCoreApplication::translate("CrlDetail", "&Status", nullptr));
        tabview->setTabText(tabview->indexOf(Widget9), QCoreApplication::translate("CrlDetail", "&Issuer", nullptr));
        tabview->setTabText(tabview->indexOf(unnamed_1), QCoreApplication::translate("CrlDetail", "&Extensions", nullptr));
        tabview->setTabText(tabview->indexOf(tab), QCoreApplication::translate("CrlDetail", "&Revocation list", nullptr));
        tabview->setTabText(tabview->indexOf(tab_2), QCoreApplication::translate("CrlDetail", "Comment", nullptr));
        (void)CrlDetail;
    } // retranslateUi

};

namespace Ui {
    class CrlDetail: public Ui_CrlDetail {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CRLDETAIL_H
