/********************************************************************************
** Form generated from reading UI file 'OidResolver.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OIDRESOLVER_H
#define UI_OIDRESOLVER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <widgets/clicklabel.h>

QT_BEGIN_NAMESPACE

class Ui_OidResolver
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *headerLabel;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QLabel *label_7;
    QLineEdit *input;
    QFrame *line;
    QFormLayout *formLayout;
    QLabel *label;
    CopyLabel *oid;
    CopyLabel *sn;
    QLabel *label_3;
    CopyLabel *ln;
    QLabel *label_4;
    CopyLabel *nid;
    QLabel *label_2;

    void setupUi(QWidget *OidResolver)
    {
        if (OidResolver->objectName().isEmpty())
            OidResolver->setObjectName("OidResolver");
        OidResolver->resize(404, 241);
        verticalLayout = new QVBoxLayout(OidResolver);
        verticalLayout->setObjectName("verticalLayout");
        headerLabel = new QLabel(OidResolver);
        headerLabel->setObjectName("headerLabel");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        headerLabel->setFont(font);
        headerLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(headerLabel);

        label_5 = new QLabel(OidResolver);
        label_5->setObjectName("label_5");

        verticalLayout->addWidget(label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_7 = new QLabel(OidResolver);
        label_7->setObjectName("label_7");

        horizontalLayout->addWidget(label_7);

        input = new QLineEdit(OidResolver);
        input->setObjectName("input");

        horizontalLayout->addWidget(input);


        verticalLayout->addLayout(horizontalLayout);

        line = new QFrame(OidResolver);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label = new QLabel(OidResolver);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::LabelRole, label);

        oid = new CopyLabel(OidResolver);
        oid->setObjectName("oid");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(oid->sizePolicy().hasHeightForWidth());
        oid->setSizePolicy(sizePolicy);
        oid->setMinimumSize(QSize(0, 18));
        oid->setText(QString::fromUtf8(""));

        formLayout->setWidget(0, QFormLayout::FieldRole, oid);

        sn = new CopyLabel(OidResolver);
        sn->setObjectName("sn");
        sizePolicy.setHeightForWidth(sn->sizePolicy().hasHeightForWidth());
        sn->setSizePolicy(sizePolicy);
        sn->setMinimumSize(QSize(0, 18));

        formLayout->setWidget(1, QFormLayout::FieldRole, sn);

        label_3 = new QLabel(OidResolver);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::LabelRole, label_3);

        ln = new CopyLabel(OidResolver);
        ln->setObjectName("ln");
        sizePolicy.setHeightForWidth(ln->sizePolicy().hasHeightForWidth());
        ln->setSizePolicy(sizePolicy);
        ln->setMinimumSize(QSize(0, 18));

        formLayout->setWidget(2, QFormLayout::FieldRole, ln);

        label_4 = new QLabel(OidResolver);
        label_4->setObjectName("label_4");

        formLayout->setWidget(3, QFormLayout::LabelRole, label_4);

        nid = new CopyLabel(OidResolver);
        nid->setObjectName("nid");
        sizePolicy.setHeightForWidth(nid->sizePolicy().hasHeightForWidth());
        nid->setSizePolicy(sizePolicy);
        nid->setMinimumSize(QSize(0, 18));

        formLayout->setWidget(3, QFormLayout::FieldRole, nid);

        label_2 = new QLabel(OidResolver);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::LabelRole, label_2);


        verticalLayout->addLayout(formLayout);


        retranslateUi(OidResolver);
        QObject::connect(input, SIGNAL(textChanged(QString)), OidResolver, SLOT(searchOid(QString)));

        QMetaObject::connectSlotsByName(OidResolver);
    } // setupUi

    void retranslateUi(QWidget *OidResolver)
    {
        headerLabel->setText(QCoreApplication::translate("OidResolver", "OID Resolver", nullptr));
        label_5->setText(QCoreApplication::translate("OidResolver", "Enter the OID, the Nid, or one of the textual representations", nullptr));
        label_7->setText(QCoreApplication::translate("OidResolver", "Search", nullptr));
        label->setText(QCoreApplication::translate("OidResolver", "OID", nullptr));
        sn->setText(QString());
        label_3->setText(QCoreApplication::translate("OidResolver", "Long name", nullptr));
        ln->setText(QString());
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QCoreApplication::translate("OidResolver", "OpenSSL internal ID", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("OidResolver", "Nid", nullptr));
#if QT_CONFIG(tooltip)
        nid->setToolTip(QCoreApplication::translate("OidResolver", "OpenSSL internal ID", nullptr));
#endif // QT_CONFIG(tooltip)
        nid->setText(QString());
        label_2->setText(QCoreApplication::translate("OidResolver", "Short name", nullptr));
        (void)OidResolver;
    } // retranslateUi

};

namespace Ui {
    class OidResolver: public Ui_OidResolver {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OIDRESOLVER_H
