/********************************************************************************
** Form generated from reading UI file 'ImportMulti.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTMULTI_H
#define UI_IMPORTMULTI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ImportMulti
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *_2;
    QLabel *heading;
    QSpacerItem *spacerItem;
    QLabel *image;
    QHBoxLayout *horizontalLayout;
    QListView *listView;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QPushButton *butOk;
    QPushButton *butImport;
    QPushButton *butCancel;
    QPushButton *butRemove;
    QPushButton *butDetails;
    QPushButton *deleteToken;
    QPushButton *renameToken;
    QSpacerItem *spacerItem1;
    QLabel *slotInfo;

    void setupUi(QDialog *ImportMulti)
    {
        if (ImportMulti->objectName().isEmpty())
            ImportMulti->setObjectName("ImportMulti");
        ImportMulti->resize(516, 477);
        verticalLayout_2 = new QVBoxLayout(ImportMulti);
        verticalLayout_2->setObjectName("verticalLayout_2");
        _2 = new QHBoxLayout();
#ifndef Q_OS_MAC
        _2->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        _2->setContentsMargins(0, 0, 0, 0);
#endif
        _2->setObjectName("_2");
        heading = new QLabel(ImportMulti);
        heading->setObjectName("heading");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        heading->setFont(font);

        _2->addWidget(heading);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _2->addItem(spacerItem);

        image = new QLabel(ImportMulti);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        _2->addWidget(image);


        verticalLayout_2->addLayout(_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        listView = new QListView(ImportMulti);
        listView->setObjectName("listView");

        horizontalLayout->addWidget(listView);

        frame = new QFrame(ImportMulti);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Box);
        frame->setFrameShadow(QFrame::Sunken);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setObjectName("verticalLayout");
        butOk = new QPushButton(frame);
        butOk->setObjectName("butOk");

        verticalLayout->addWidget(butOk);

        butImport = new QPushButton(frame);
        butImport->setObjectName("butImport");

        verticalLayout->addWidget(butImport);

        butCancel = new QPushButton(frame);
        butCancel->setObjectName("butCancel");

        verticalLayout->addWidget(butCancel);

        butRemove = new QPushButton(frame);
        butRemove->setObjectName("butRemove");

        verticalLayout->addWidget(butRemove);

        butDetails = new QPushButton(frame);
        butDetails->setObjectName("butDetails");

        verticalLayout->addWidget(butDetails);

        deleteToken = new QPushButton(frame);
        deleteToken->setObjectName("deleteToken");

        verticalLayout->addWidget(deleteToken);

        renameToken = new QPushButton(frame);
        renameToken->setObjectName("renameToken");

        verticalLayout->addWidget(renameToken);

        spacerItem1 = new QSpacerItem(204, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem1);

        slotInfo = new QLabel(frame);
        slotInfo->setObjectName("slotInfo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(slotInfo->sizePolicy().hasHeightForWidth());
        slotInfo->setSizePolicy(sizePolicy);
        slotInfo->setFrameShape(QFrame::Box);

        verticalLayout->addWidget(slotInfo);


        horizontalLayout->addWidget(frame);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(ImportMulti);
        QObject::connect(butCancel, &QPushButton::clicked, ImportMulti, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(ImportMulti);
    } // setupUi

    void retranslateUi(QDialog *ImportMulti)
    {
        heading->setText(QCoreApplication::translate("ImportMulti", "Import PKI Items", nullptr));
        butOk->setText(QCoreApplication::translate("ImportMulti", "Import &All", nullptr));
        butImport->setText(QCoreApplication::translate("ImportMulti", "&Import", nullptr));
        butCancel->setText(QCoreApplication::translate("ImportMulti", "&Done", nullptr));
        butRemove->setText(QCoreApplication::translate("ImportMulti", "&Remove from list", nullptr));
        butDetails->setText(QCoreApplication::translate("ImportMulti", "Details", nullptr));
        deleteToken->setText(QCoreApplication::translate("ImportMulti", "Delete from token", nullptr));
        renameToken->setText(QCoreApplication::translate("ImportMulti", "Rename on token", nullptr));
        (void)ImportMulti;
    } // retranslateUi

};

namespace Ui {
    class ImportMulti: public Ui_ImportMulti {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IMPORTMULTI_H
