/********************************************************************************
** Form generated from reading UI file 'Help.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HELP_H
#define UI_HELP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Help
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *back;
    QPushButton *forward;
    QSpacerItem *spacerItem;
    QPushButton *buttonOk;
    QTextBrowser *textbox;

    void setupUi(QWidget *Help)
    {
        if (Help->objectName().isEmpty())
            Help->setObjectName("Help");
        Help->resize(737, 619);
        vboxLayout = new QVBoxLayout(Help);
#ifndef Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        back = new QPushButton(Help);
        back->setObjectName("back");
        back->setAutoDefault(true);

        hboxLayout->addWidget(back);

        forward = new QPushButton(Help);
        forward->setObjectName("forward");
        forward->setAutoDefault(true);

        hboxLayout->addWidget(forward);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonOk = new QPushButton(Help);
        buttonOk->setObjectName("buttonOk");
        buttonOk->setAutoDefault(true);

        hboxLayout->addWidget(buttonOk);


        vboxLayout->addLayout(hboxLayout);

        textbox = new QTextBrowser(Help);
        textbox->setObjectName("textbox");

        vboxLayout->addWidget(textbox);


        retranslateUi(Help);
        QObject::connect(buttonOk, &QPushButton::clicked, Help, qOverload<>(&QWidget::hide));
        QObject::connect(forward, &QPushButton::clicked, textbox, qOverload<>(&QTextBrowser::forward));
        QObject::connect(back, &QPushButton::clicked, textbox, qOverload<>(&QTextBrowser::backward));
        QObject::connect(textbox, &QTextBrowser::backwardAvailable, back, &QPushButton::setEnabled);
        QObject::connect(textbox, &QTextBrowser::forwardAvailable, forward, &QPushButton::setEnabled);

        buttonOk->setDefault(true);


        QMetaObject::connectSlotsByName(Help);
    } // setupUi

    void retranslateUi(QWidget *Help)
    {
        Help->setWindowTitle(QString());
        back->setText(QCoreApplication::translate("Help", "<<", nullptr));
        forward->setText(QCoreApplication::translate("Help", ">>", nullptr));
        buttonOk->setText(QCoreApplication::translate("Help", "&Done", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Help: public Ui_Help {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HELP_H
