/****************************************************************************
** Meta object code from reading C++ file 'XcaTreeView.h'
**
** Created by: The Qt Meta Object Compiler version 68 (Qt 6.8.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../widgets/XcaTreeView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'XcaTreeView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 68
#error "This file was generated using the moc from 6.8.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11XcaTreeViewE_t {};
} // unnamed namespace


#ifdef QT_MOC_HAS_STRINGDATA
static constexpr auto qt_meta_stringdata_ZN11XcaTreeViewE = QtMocHelpers::stringData(
    "XcaTreeView",
    "changeView",
    "",
    "showHideSections",
    "sectionMoved",
    "idx",
    "oldI",
    "newI",
    "columnsResize",
    "editIdx",
    "setFilter",
    "pattern",
    "deleteItems",
    "exportItems",
    "showItems",
    "newItem",
    "doubleClick",
    "QModelIndex",
    "m",
    "pem2clipboard",
    "headerDetails",
    "columnRemove",
    "columnsChanged",
    "editComment",
    "showItem",
    "pki_base*",
    "index",
    "name",
    "itemSelectionChanged",
    "clipboardFormat",
    "QAction*"
);
#else  // !QT_MOC_HAS_STRINGDATA
#error "qtmochelpers.h not found or too old."
#endif // !QT_MOC_HAS_STRINGDATA

Q_CONSTINIT static const uint qt_meta_data_ZN11XcaTreeViewE[] = {

 // content:
      12,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags, initial metatype offsets
       1,    0,  140,    2, 0x0a,    1 /* Public */,
       3,    0,  141,    2, 0x0a,    2 /* Public */,
       4,    3,  142,    2, 0x0a,    3 /* Public */,
       8,    0,  149,    2, 0x0a,    7 /* Public */,
       9,    0,  150,    2, 0x0a,    8 /* Public */,
      10,    1,  151,    2, 0x0a,    9 /* Public */,
      12,    0,  154,    2, 0x0a,   11 /* Public */,
      13,    0,  155,    2, 0x0a,   12 /* Public */,
      14,    0,  156,    2, 0x0a,   13 /* Public */,
      15,    0,  157,    2, 0x0a,   14 /* Public */,
      16,    1,  158,    2, 0x0a,   15 /* Public */,
      19,    0,  161,    2, 0x0a,   17 /* Public */,
      20,    0,  162,    2, 0x0a,   18 /* Public */,
      21,    0,  163,    2, 0x0a,   19 /* Public */,
      22,    0,  164,    2, 0x0a,   20 /* Public */,
      23,    0,  165,    2, 0x0a,   21 /* Public */,
      24,    1,  166,    2, 0x0a,   22 /* Public */,
      24,    1,  169,    2, 0x0a,   24 /* Public */,
      24,    1,  172,    2, 0x0a,   26 /* Public */,
      28,    2,  175,    2, 0x0a,   28 /* Public */,
      29,    1,  180,    2, 0x0a,   31 /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    5,    6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 17,   26,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, 0x80000000 | 17, 0x80000000 | 17,   18,    2,
    QMetaType::Void, 0x80000000 | 30,    2,

       0        // eod
};

Q_CONSTINIT const QMetaObject XcaTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_meta_stringdata_ZN11XcaTreeViewE.offsetsAndSizes,
    qt_meta_data_ZN11XcaTreeViewE,
    qt_static_metacall,
    nullptr,
    qt_incomplete_metaTypeArray<qt_meta_tag_ZN11XcaTreeViewE_t,
        // Q_OBJECT / Q_GADGET
        QtPrivate::TypeAndForceComplete<XcaTreeView, std::true_type>,
        // method 'changeView'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'showHideSections'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'sectionMoved'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'columnsResize'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'editIdx'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'setFilter'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'deleteItems'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'exportItems'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'showItems'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'newItem'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'doubleClick'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        // method 'pem2clipboard'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'headerDetails'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'columnRemove'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'columnsChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'editComment'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'showItem'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<pki_base *, std::false_type>,
        // method 'showItem'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        // method 'showItem'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'itemSelectionChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        // method 'clipboardFormat'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QAction *, std::false_type>
    >,
    nullptr
} };

void XcaTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XcaTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changeView(); break;
        case 1: _t->showHideSections(); break;
        case 2: _t->sectionMoved((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->columnsResize(); break;
        case 4: _t->editIdx(); break;
        case 5: _t->setFilter((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->deleteItems(); break;
        case 7: _t->exportItems(); break;
        case 8: _t->showItems(); break;
        case 9: _t->newItem(); break;
        case 10: _t->doubleClick((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->pem2clipboard(); break;
        case 12: _t->headerDetails(); break;
        case 13: _t->columnRemove(); break;
        case 14: _t->columnsChanged(); break;
        case 15: _t->editComment(); break;
        case 16: _t->showItem((*reinterpret_cast< std::add_pointer_t<pki_base*>>(_a[1]))); break;
        case 17: _t->showItem((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 18: _t->showItem((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->itemSelectionChanged((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 20: _t->clipboardFormat((*reinterpret_cast< std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *XcaTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XcaTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ZN11XcaTreeViewE.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int XcaTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
