/****************************************************************************
** Meta object code from reading C++ file 'db_base.h'
**
** Created by: The Qt Meta Object Compiler version 68 (Qt 6.8.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../lib/db_base.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'db_base.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 68
#error "This file was generated using the moc from 6.8.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7db_baseE_t {};
} // unnamed namespace


#ifdef QT_MOC_HAS_STRINGDATA
static constexpr auto qt_meta_stringdata_ZN7db_baseE = QtMocHelpers::stringData(
    "db_base",
    "resetHeader",
    "",
    "updateHeader",
    "columnsContentChanged",
    "pkiChanged",
    "pki_base*",
    "pki",
    "newItem",
    "columnResetDefaults",
    "sectionResized",
    "i",
    "newSize",
    "sortIndicatorChanged",
    "Qt::SortOrder",
    "setSelected",
    "QVariant",
    "v",
    "timerMaintenance"
);
#else  // !QT_MOC_HAS_STRINGDATA
#error "qtmochelpers.h not found or too old."
#endif // !QT_MOC_HAS_STRINGDATA

Q_CONSTINIT static const uint qt_meta_data_ZN7db_baseE[] = {

 // content:
      12,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags, initial metatype offsets
       1,    0,   74,    2, 0x106,    1 /* Public | MethodIsConst  */,
       3,    0,   75,    2, 0x106,    2 /* Public | MethodIsConst  */,
       4,    0,   76,    2, 0x106,    3 /* Public | MethodIsConst  */,
       5,    1,   77,    2, 0x106,    4 /* Public | MethodIsConst  */,

 // slots: name, argc, parameters, tag, flags, initial metatype offsets
       8,    0,   80,    2, 0x0a,    6 /* Public */,
       9,    0,   81,    2, 0x0a,    7 /* Public */,
      10,    3,   82,    2, 0x0a,    8 /* Public */,
      13,    2,   89,    2, 0x0a,   12 /* Public */,
      15,    1,   94,    2, 0x0a,   15 /* Public */,
      18,    0,   97,    2, 0x0a,   17 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,   11,    2,   12,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 14,    2,    2,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,

       0        // eod
};

Q_CONSTINIT const QMetaObject db_base::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_meta_stringdata_ZN7db_baseE.offsetsAndSizes,
    qt_meta_data_ZN7db_baseE,
    qt_static_metacall,
    nullptr,
    qt_incomplete_metaTypeArray<qt_meta_tag_ZN7db_baseE_t,
        // Q_OBJECT / Q_GADGET
        QtPrivate::TypeAndForceComplete<db_base, std::true_type>,
        // method 'resetHeader'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'updateHeader'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'columnsContentChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'pkiChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<pki_base *, std::false_type>,
        // method 'newItem'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'columnResetDefaults'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'sectionResized'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'sortIndicatorChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<Qt::SortOrder, std::false_type>,
        // method 'setSelected'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QVariant &, std::false_type>,
        // method 'timerMaintenance'
        QtPrivate::TypeAndForceComplete<void, std::false_type>
    >,
    nullptr
} };

void db_base::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<db_base *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resetHeader(); break;
        case 1: _t->updateHeader(); break;
        case 2: _t->columnsContentChanged(); break;
        case 3: _t->pkiChanged((*reinterpret_cast< std::add_pointer_t<pki_base*>>(_a[1]))); break;
        case 4: _t->newItem(); break;
        case 5: _t->columnResetDefaults(); break;
        case 6: _t->sectionResized((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->sortIndicatorChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<Qt::SortOrder>>(_a[2]))); break;
        case 8: _t->setSelected((*reinterpret_cast< std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 9: _t->timerMaintenance(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< pki_base* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _q_method_type = void (db_base::*)() const;
            if (_q_method_type _q_method = &db_base::resetHeader; *reinterpret_cast<_q_method_type *>(_a[1]) == _q_method) {
                *result = 0;
                return;
            }
        }
        {
            using _q_method_type = void (db_base::*)() const;
            if (_q_method_type _q_method = &db_base::updateHeader; *reinterpret_cast<_q_method_type *>(_a[1]) == _q_method) {
                *result = 1;
                return;
            }
        }
        {
            using _q_method_type = void (db_base::*)() const;
            if (_q_method_type _q_method = &db_base::columnsContentChanged; *reinterpret_cast<_q_method_type *>(_a[1]) == _q_method) {
                *result = 2;
                return;
            }
        }
        {
            using _q_method_type = void (db_base::*)(pki_base * ) const;
            if (_q_method_type _q_method = &db_base::pkiChanged; *reinterpret_cast<_q_method_type *>(_a[1]) == _q_method) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject *db_base::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *db_base::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ZN7db_baseE.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int db_base::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void db_base::resetHeader()const
{
    QMetaObject::activate(const_cast< db_base *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void db_base::updateHeader()const
{
    QMetaObject::activate(const_cast< db_base *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void db_base::columnsContentChanged()const
{
    QMetaObject::activate(const_cast< db_base *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void db_base::pkiChanged(pki_base * _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< db_base *>(this), &staticMetaObject, 3, _a);
}
QT_WARNING_POP
