/********************************************************************************
** Form generated from reading UI file 'NewCrl.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWCRL_H
#define UI_NEWCRL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/hashBox.h"
#include "widgets/validity.h"

QT_BEGIN_NAMESPACE

class Ui_NewCrl
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *dateBox;
    QVBoxLayout *verticalLayout;
    QWidget *widget;
    QGridLayout *gridLayout_2;
    QLabel *label;
    Validity *lastUpdate;
    QLabel *label_2;
    Validity *nextUpdate;
    QWidget *widget_2;
    QGridLayout *gridLayout;
    QLineEdit *validNumber;
    QComboBox *validRange;
    QCheckBox *midnightCB;
    QCheckBox *checkBox;
    QPushButton *applyTime;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QLabel *label_3;
    hashBox *hashAlgo;
    QLabel *label_6;
    QCheckBox *subAltName;
    QLabel *label_5;
    QCheckBox *authKeyId;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout;
    QCheckBox *setCrlNumber;
    QLineEdit *crlNumber;
    QLabel *label_7;
    QCheckBox *revocationReasons;

    void setupUi(QWidget *NewCrl)
    {
        if (NewCrl->objectName().isEmpty())
            NewCrl->setObjectName("NewCrl");
        NewCrl->resize(354, 428);
        verticalLayout_2 = new QVBoxLayout(NewCrl);
        verticalLayout_2->setObjectName("verticalLayout_2");
        dateBox = new QGroupBox(NewCrl);
        dateBox->setObjectName("dateBox");
        verticalLayout = new QVBoxLayout(dateBox);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
        widget = new QWidget(dateBox);
        widget->setObjectName("widget");
        gridLayout_2 = new QGridLayout(widget);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(widget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        lastUpdate = new Validity(widget);
        lastUpdate->setObjectName("lastUpdate");
        lastUpdate->setCalendarPopup(true);

        gridLayout_2->addWidget(lastUpdate, 0, 1, 1, 1);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        nextUpdate = new Validity(widget);
        nextUpdate->setObjectName("nextUpdate");
        nextUpdate->setCalendarPopup(true);

        gridLayout_2->addWidget(nextUpdate, 1, 1, 1, 1);


        verticalLayout->addWidget(widget);

        widget_2 = new QWidget(dateBox);
        widget_2->setObjectName("widget_2");
        gridLayout = new QGridLayout(widget_2);
        gridLayout->setObjectName("gridLayout");
        validNumber = new QLineEdit(widget_2);
        validNumber->setObjectName("validNumber");

        gridLayout->addWidget(validNumber, 0, 0, 1, 2);

        validRange = new QComboBox(widget_2);
        validRange->addItem(QString());
        validRange->addItem(QString());
        validRange->addItem(QString());
        validRange->setObjectName("validRange");

        gridLayout->addWidget(validRange, 0, 2, 1, 1);

        midnightCB = new QCheckBox(widget_2);
        midnightCB->setObjectName("midnightCB");

        gridLayout->addWidget(midnightCB, 1, 0, 1, 1);

        checkBox = new QCheckBox(widget_2);
        checkBox->setObjectName("checkBox");

        gridLayout->addWidget(checkBox, 1, 1, 1, 1);

        applyTime = new QPushButton(widget_2);
        applyTime->setObjectName("applyTime");

        gridLayout->addWidget(applyTime, 1, 2, 1, 1);


        verticalLayout->addWidget(widget_2);


        verticalLayout_2->addWidget(dateBox);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        groupBox_2 = new QGroupBox(NewCrl);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName("gridLayout_3");
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout_3->addWidget(label_3, 0, 0, 1, 1);

        hashAlgo = new hashBox(groupBox_2);
        hashAlgo->setObjectName("hashAlgo");

        gridLayout_3->addWidget(hashAlgo, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        gridLayout_3->addWidget(label_6, 1, 0, 1, 1);

        subAltName = new QCheckBox(groupBox_2);
        subAltName->setObjectName("subAltName");

        gridLayout_3->addWidget(subAltName, 1, 1, 1, 1);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        gridLayout_3->addWidget(label_5, 2, 0, 1, 1);

        authKeyId = new QCheckBox(groupBox_2);
        authKeyId->setObjectName("authKeyId");

        gridLayout_3->addWidget(authKeyId, 2, 1, 1, 1);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        gridLayout_3->addWidget(label_4, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        setCrlNumber = new QCheckBox(groupBox_2);
        setCrlNumber->setObjectName("setCrlNumber");
        setCrlNumber->setChecked(true);

        horizontalLayout->addWidget(setCrlNumber);

        crlNumber = new QLineEdit(groupBox_2);
        crlNumber->setObjectName("crlNumber");

        horizontalLayout->addWidget(crlNumber);


        gridLayout_3->addLayout(horizontalLayout, 3, 1, 1, 1);

        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 4, 0, 1, 1);

        revocationReasons = new QCheckBox(groupBox_2);
        revocationReasons->setObjectName("revocationReasons");
        revocationReasons->setChecked(true);

        gridLayout_3->addWidget(revocationReasons, 4, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox_2);


        retranslateUi(NewCrl);
        QObject::connect(setCrlNumber, &QCheckBox::clicked, crlNumber, &QLineEdit::setEnabled);
        QObject::connect(midnightCB, SIGNAL(stateChanged(int)), nextUpdate, SLOT(hideTimeCheck(int)));
        QObject::connect(midnightCB, SIGNAL(stateChanged(int)), lastUpdate, SLOT(hideTimeCheck(int)));
        QObject::connect(midnightCB, &QCheckBox::clicked, checkBox, &QCheckBox::setDisabled);
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), nextUpdate, SLOT(localTime(int)));
        QObject::connect(checkBox, SIGNAL(stateChanged(int)), lastUpdate, SLOT(localTime(int)));

        QMetaObject::connectSlotsByName(NewCrl);
    } // setupUi

    void retranslateUi(QWidget *NewCrl)
    {
        NewCrl->setWindowTitle(QString());
        dateBox->setTitle(QString());
        label->setText(QCoreApplication::translate("NewCrl", "Last update", nullptr));
        label_2->setText(QCoreApplication::translate("NewCrl", "Next update", nullptr));
        validRange->setItemText(0, QCoreApplication::translate("NewCrl", "Days", nullptr));
        validRange->setItemText(1, QCoreApplication::translate("NewCrl", "Months", nullptr));
        validRange->setItemText(2, QCoreApplication::translate("NewCrl", "Years", nullptr));

        midnightCB->setText(QCoreApplication::translate("NewCrl", "Midnight", nullptr));
        checkBox->setText(QCoreApplication::translate("NewCrl", "Local time", nullptr));
        applyTime->setText(QCoreApplication::translate("NewCrl", "Apply", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("NewCrl", "Options", nullptr));
        label_3->setText(QCoreApplication::translate("NewCrl", "Hash algorithm", nullptr));
        label_6->setText(QCoreApplication::translate("NewCrl", "Subject alternative name", nullptr));
        subAltName->setText(QString());
        label_5->setText(QCoreApplication::translate("NewCrl", "Authority key identifier", nullptr));
        authKeyId->setText(QString());
        label_4->setText(QCoreApplication::translate("NewCrl", "CRL number", nullptr));
        setCrlNumber->setText(QString());
        label_7->setText(QCoreApplication::translate("NewCrl", "Revocation reasons", nullptr));
        revocationReasons->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class NewCrl: public Ui_NewCrl {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NEWCRL_H
