/********************************************************************************
** Form generated from reading UI file 'MainWindow.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/CertTreeView.h"
#include "widgets/CrlTreeView.h"
#include "widgets/KeyTreeView.h"
#include "widgets/ReqTreeView.h"
#include "widgets/TempTreeView.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QWidget *centralWidget;
    QVBoxLayout *la;
    QTabWidget *tabView;
    QWidget *KeyTab;
    QHBoxLayout *layout_2;
    KeyTreeView *keyView;
    QFrame *keyButtons;
    QVBoxLayout *verticalLayout;
    QPushButton *BNnewKey;
    QPushButton *BNexportKey;
    QPushButton *BNimportKey;
    QPushButton *BNimportPFX;
    QPushButton *BNdetailsKey;
    QPushButton *BNdeleteKey;
    QSpacerItem *spacerItem;
    QLabel *bigKey;
    QWidget *CSRTab;
    QHBoxLayout *horizontalLayout;
    ReqTreeView *reqView;
    QFrame *reqButtons;
    QVBoxLayout *vboxLayout;
    QPushButton *BNnewReq;
    QPushButton *BNexportReq;
    QPushButton *BNimportReq;
    QPushButton *BNdetailsReq;
    QPushButton *BNdeleteReq;
    QSpacerItem *spacerItem1;
    QLabel *bigCsr;
    QWidget *CertTab;
    QHBoxLayout *layout;
    CertTreeView *certView;
    QFrame *certButtons;
    QVBoxLayout *vboxLayout1;
    QPushButton *BNnewCert;
    QPushButton *BNexportCert;
    QPushButton *BNimportCert;
    QPushButton *BNdetailsCert;
    QPushButton *BNdeleteCert;
    QPushButton *BNimportPKCS12;
    QPushButton *BNimportPKCS7;
    QPushButton *BNviewState;
    QSpacerItem *spacerItem2;
    QLabel *bigCert;
    QWidget *TemplateTab;
    QHBoxLayout *layout_4;
    TempTreeView *tempView;
    QFrame *tempButtons;
    QVBoxLayout *_3;
    QPushButton *BNnewTemp;
    QPushButton *BNchangeTemp;
    QPushButton *BNdeleteTemp;
    QPushButton *BNimportTemp;
    QPushButton *BNexportTemp;
    QSpacerItem *spacerItem3;
    QLabel *bigTemp;
    QWidget *CRLTab;
    QHBoxLayout *crl_2;
    CrlTreeView *crlView;
    QFrame *crlButtons;
    QVBoxLayout *vboxLayout2;
    QPushButton *BNnewCrl;
    QPushButton *BNexportCrl;
    QPushButton *BNimportCrl;
    QPushButton *BNdetailsCrl;
    QPushButton *BNdeleteCrl;
    QSpacerItem *spacerItem4;
    QLabel *bigRev;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(702, 511);
        centralWidget = new QWidget(MainWindow);
        centralWidget->setObjectName("centralWidget");
        la = new QVBoxLayout(centralWidget);
        la->setObjectName("la");
        tabView = new QTabWidget(centralWidget);
        tabView->setObjectName("tabView");
        tabView->setEnabled(true);
        KeyTab = new QWidget();
        KeyTab->setObjectName("KeyTab");
        layout_2 = new QHBoxLayout(KeyTab);
        layout_2->setObjectName("layout_2");
        keyView = new KeyTreeView(KeyTab);
        keyView->setObjectName("keyView");

        layout_2->addWidget(keyView);

        keyButtons = new QFrame(KeyTab);
        keyButtons->setObjectName("keyButtons");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(keyButtons->sizePolicy().hasHeightForWidth());
        keyButtons->setSizePolicy(sizePolicy);
        keyButtons->setFrameShape(QFrame::Box);
        keyButtons->setFrameShadow(QFrame::Sunken);
        verticalLayout = new QVBoxLayout(keyButtons);
        verticalLayout->setObjectName("verticalLayout");
        BNnewKey = new QPushButton(keyButtons);
        BNnewKey->setObjectName("BNnewKey");

        verticalLayout->addWidget(BNnewKey);

        BNexportKey = new QPushButton(keyButtons);
        BNexportKey->setObjectName("BNexportKey");

        verticalLayout->addWidget(BNexportKey);

        BNimportKey = new QPushButton(keyButtons);
        BNimportKey->setObjectName("BNimportKey");

        verticalLayout->addWidget(BNimportKey);

        BNimportPFX = new QPushButton(keyButtons);
        BNimportPFX->setObjectName("BNimportPFX");

        verticalLayout->addWidget(BNimportPFX);

        BNdetailsKey = new QPushButton(keyButtons);
        BNdetailsKey->setObjectName("BNdetailsKey");

        verticalLayout->addWidget(BNdetailsKey);

        BNdeleteKey = new QPushButton(keyButtons);
        BNdeleteKey->setObjectName("BNdeleteKey");

        verticalLayout->addWidget(BNdeleteKey);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);

        bigKey = new QLabel(keyButtons);
        bigKey->setObjectName("bigKey");
        bigKey->setMinimumSize(QSize(200, 94));
        bigKey->setScaledContents(true);

        verticalLayout->addWidget(bigKey);


        layout_2->addWidget(keyButtons);

        tabView->addTab(KeyTab, QString());
        CSRTab = new QWidget();
        CSRTab->setObjectName("CSRTab");
        horizontalLayout = new QHBoxLayout(CSRTab);
        horizontalLayout->setObjectName("horizontalLayout");
        reqView = new ReqTreeView(CSRTab);
        reqView->setObjectName("reqView");

        horizontalLayout->addWidget(reqView);

        reqButtons = new QFrame(CSRTab);
        reqButtons->setObjectName("reqButtons");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(reqButtons->sizePolicy().hasHeightForWidth());
        reqButtons->setSizePolicy(sizePolicy1);
        reqButtons->setFrameShape(QFrame::Box);
        reqButtons->setFrameShadow(QFrame::Sunken);
        vboxLayout = new QVBoxLayout(reqButtons);
        vboxLayout->setObjectName("vboxLayout");
        BNnewReq = new QPushButton(reqButtons);
        BNnewReq->setObjectName("BNnewReq");

        vboxLayout->addWidget(BNnewReq);

        BNexportReq = new QPushButton(reqButtons);
        BNexportReq->setObjectName("BNexportReq");

        vboxLayout->addWidget(BNexportReq);

        BNimportReq = new QPushButton(reqButtons);
        BNimportReq->setObjectName("BNimportReq");

        vboxLayout->addWidget(BNimportReq);

        BNdetailsReq = new QPushButton(reqButtons);
        BNdetailsReq->setObjectName("BNdetailsReq");

        vboxLayout->addWidget(BNdetailsReq);

        BNdeleteReq = new QPushButton(reqButtons);
        BNdeleteReq->setObjectName("BNdeleteReq");

        vboxLayout->addWidget(BNdeleteReq);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);

        bigCsr = new QLabel(reqButtons);
        bigCsr->setObjectName("bigCsr");
        bigCsr->setMinimumSize(QSize(200, 94));
        bigCsr->setScaledContents(true);

        vboxLayout->addWidget(bigCsr);


        horizontalLayout->addWidget(reqButtons);

        tabView->addTab(CSRTab, QString());
        CertTab = new QWidget();
        CertTab->setObjectName("CertTab");
        layout = new QHBoxLayout(CertTab);
        layout->setObjectName("layout");
        certView = new CertTreeView(CertTab);
        certView->setObjectName("certView");

        layout->addWidget(certView);

        certButtons = new QFrame(CertTab);
        certButtons->setObjectName("certButtons");
        certButtons->setFrameShape(QFrame::Box);
        certButtons->setFrameShadow(QFrame::Sunken);
        vboxLayout1 = new QVBoxLayout(certButtons);
        vboxLayout1->setObjectName("vboxLayout1");
        BNnewCert = new QPushButton(certButtons);
        BNnewCert->setObjectName("BNnewCert");

        vboxLayout1->addWidget(BNnewCert);

        BNexportCert = new QPushButton(certButtons);
        BNexportCert->setObjectName("BNexportCert");

        vboxLayout1->addWidget(BNexportCert);

        BNimportCert = new QPushButton(certButtons);
        BNimportCert->setObjectName("BNimportCert");

        vboxLayout1->addWidget(BNimportCert);

        BNdetailsCert = new QPushButton(certButtons);
        BNdetailsCert->setObjectName("BNdetailsCert");

        vboxLayout1->addWidget(BNdetailsCert);

        BNdeleteCert = new QPushButton(certButtons);
        BNdeleteCert->setObjectName("BNdeleteCert");

        vboxLayout1->addWidget(BNdeleteCert);

        BNimportPKCS12 = new QPushButton(certButtons);
        BNimportPKCS12->setObjectName("BNimportPKCS12");

        vboxLayout1->addWidget(BNimportPKCS12);

        BNimportPKCS7 = new QPushButton(certButtons);
        BNimportPKCS7->setObjectName("BNimportPKCS7");

        vboxLayout1->addWidget(BNimportPKCS7);

        BNviewState = new QPushButton(certButtons);
        BNviewState->setObjectName("BNviewState");

        vboxLayout1->addWidget(BNviewState);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem2);

        bigCert = new QLabel(certButtons);
        bigCert->setObjectName("bigCert");
        bigCert->setMinimumSize(QSize(200, 94));
        bigCert->setScaledContents(true);

        vboxLayout1->addWidget(bigCert);


        layout->addWidget(certButtons);

        tabView->addTab(CertTab, QString());
        TemplateTab = new QWidget();
        TemplateTab->setObjectName("TemplateTab");
        layout_4 = new QHBoxLayout(TemplateTab);
        layout_4->setObjectName("layout_4");
        tempView = new TempTreeView(TemplateTab);
        tempView->setObjectName("tempView");

        layout_4->addWidget(tempView);

        tempButtons = new QFrame(TemplateTab);
        tempButtons->setObjectName("tempButtons");
        tempButtons->setFrameShape(QFrame::Box);
        tempButtons->setFrameShadow(QFrame::Sunken);
        _3 = new QVBoxLayout(tempButtons);
        _3->setObjectName("_3");
        BNnewTemp = new QPushButton(tempButtons);
        BNnewTemp->setObjectName("BNnewTemp");

        _3->addWidget(BNnewTemp);

        BNchangeTemp = new QPushButton(tempButtons);
        BNchangeTemp->setObjectName("BNchangeTemp");

        _3->addWidget(BNchangeTemp);

        BNdeleteTemp = new QPushButton(tempButtons);
        BNdeleteTemp->setObjectName("BNdeleteTemp");

        _3->addWidget(BNdeleteTemp);

        BNimportTemp = new QPushButton(tempButtons);
        BNimportTemp->setObjectName("BNimportTemp");

        _3->addWidget(BNimportTemp);

        BNexportTemp = new QPushButton(tempButtons);
        BNexportTemp->setObjectName("BNexportTemp");

        _3->addWidget(BNexportTemp);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        _3->addItem(spacerItem3);

        bigTemp = new QLabel(tempButtons);
        bigTemp->setObjectName("bigTemp");
        bigTemp->setMinimumSize(QSize(200, 94));
        bigTemp->setScaledContents(true);

        _3->addWidget(bigTemp);


        layout_4->addWidget(tempButtons);

        tabView->addTab(TemplateTab, QString());
        CRLTab = new QWidget();
        CRLTab->setObjectName("CRLTab");
        crl_2 = new QHBoxLayout(CRLTab);
        crl_2->setObjectName("crl_2");
        crlView = new CrlTreeView(CRLTab);
        crlView->setObjectName("crlView");

        crl_2->addWidget(crlView);

        crlButtons = new QFrame(CRLTab);
        crlButtons->setObjectName("crlButtons");
        crlButtons->setFrameShape(QFrame::Box);
        crlButtons->setFrameShadow(QFrame::Sunken);
        vboxLayout2 = new QVBoxLayout(crlButtons);
        vboxLayout2->setObjectName("vboxLayout2");
        BNnewCrl = new QPushButton(crlButtons);
        BNnewCrl->setObjectName("BNnewCrl");

        vboxLayout2->addWidget(BNnewCrl);

        BNexportCrl = new QPushButton(crlButtons);
        BNexportCrl->setObjectName("BNexportCrl");

        vboxLayout2->addWidget(BNexportCrl);

        BNimportCrl = new QPushButton(crlButtons);
        BNimportCrl->setObjectName("BNimportCrl");

        vboxLayout2->addWidget(BNimportCrl);

        BNdetailsCrl = new QPushButton(crlButtons);
        BNdetailsCrl->setObjectName("BNdetailsCrl");

        vboxLayout2->addWidget(BNdetailsCrl);

        BNdeleteCrl = new QPushButton(crlButtons);
        BNdeleteCrl->setObjectName("BNdeleteCrl");

        vboxLayout2->addWidget(BNdeleteCrl);

        spacerItem4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem4);

        bigRev = new QLabel(crlButtons);
        bigRev->setObjectName("bigRev");
        bigRev->setMinimumSize(QSize(200, 94));
        bigRev->setScaledContents(true);

        vboxLayout2->addWidget(bigRev);


        crl_2->addWidget(crlButtons);

        tabView->addTab(CRLTab, QString());

        la->addWidget(tabView);

        MainWindow->setCentralWidget(centralWidget);

        retranslateUi(MainWindow);
        QObject::connect(BNimportKey, &QPushButton::clicked, keyView, qOverload<>(&KeyTreeView::load));
        QObject::connect(BNnewKey, &QPushButton::clicked, keyView, qOverload<>(&KeyTreeView::newItem));
        QObject::connect(BNexportKey, &QPushButton::clicked, keyView, qOverload<>(&KeyTreeView::exportItems));
        QObject::connect(BNdetailsKey, &QPushButton::clicked, keyView, qOverload<>(&KeyTreeView::showItems));
        QObject::connect(BNdeleteKey, &QPushButton::clicked, keyView, qOverload<>(&KeyTreeView::deleteItems));
        QObject::connect(BNnewReq, &QPushButton::clicked, reqView, qOverload<>(&ReqTreeView::newItem));
        QObject::connect(BNexportReq, &QPushButton::clicked, reqView, qOverload<>(&ReqTreeView::exportItems));
        QObject::connect(BNimportReq, &QPushButton::clicked, reqView, qOverload<>(&ReqTreeView::load));
        QObject::connect(BNdetailsReq, &QPushButton::clicked, reqView, qOverload<>(&ReqTreeView::showItems));
        QObject::connect(BNdeleteReq, &QPushButton::clicked, reqView, qOverload<>(&ReqTreeView::deleteItems));
        QObject::connect(BNnewCert, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::newItem));
        QObject::connect(BNexportCert, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::exportItems));
        QObject::connect(BNimportCert, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::load));
        QObject::connect(BNdetailsCert, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::showItems));
        QObject::connect(BNdeleteCert, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::deleteItems));
        QObject::connect(BNnewTemp, &QPushButton::clicked, tempView, qOverload<>(&TempTreeView::newItem));
        QObject::connect(BNchangeTemp, &QPushButton::clicked, tempView, qOverload<>(&TempTreeView::showItems));
        QObject::connect(BNdeleteTemp, &QPushButton::clicked, tempView, qOverload<>(&TempTreeView::deleteItems));
        QObject::connect(BNimportTemp, &QPushButton::clicked, tempView, qOverload<>(&TempTreeView::load));
        QObject::connect(BNexportTemp, &QPushButton::clicked, tempView, qOverload<>(&TempTreeView::exportItems));
        QObject::connect(BNexportCrl, &QPushButton::clicked, crlView, qOverload<>(&CrlTreeView::exportItems));
        QObject::connect(BNimportCrl, &QPushButton::clicked, crlView, qOverload<>(&CrlTreeView::load));
        QObject::connect(BNdetailsCrl, &QPushButton::clicked, crlView, qOverload<>(&CrlTreeView::showItems));
        QObject::connect(BNdeleteCrl, &QPushButton::clicked, crlView, qOverload<>(&CrlTreeView::deleteItems));
        QObject::connect(BNimportPKCS12, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::loadPKCS12));
        QObject::connect(BNimportPKCS7, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::loadPKCS7));
        QObject::connect(BNimportPFX, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::loadPKCS12));
        QObject::connect(BNviewState, &QPushButton::clicked, certView, qOverload<>(&CertTreeView::changeView));
        QObject::connect(BNnewCrl, &QPushButton::clicked, crlView, qOverload<>(&CrlTreeView::newItem));

        tabView->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        BNnewKey->setText(QCoreApplication::translate("MainWindow", "&New Key", nullptr));
        BNexportKey->setText(QCoreApplication::translate("MainWindow", "&Export", nullptr));
        BNimportKey->setText(QCoreApplication::translate("MainWindow", "&Import", nullptr));
        BNimportPFX->setText(QCoreApplication::translate("MainWindow", "Import PFX (PKCS#12)", nullptr));
        BNdetailsKey->setText(QCoreApplication::translate("MainWindow", "&Show Details", nullptr));
        BNdeleteKey->setText(QCoreApplication::translate("MainWindow", "&Delete", nullptr));
        tabView->setTabText(tabView->indexOf(KeyTab), QCoreApplication::translate("MainWindow", "Private Keys", nullptr));
        BNnewReq->setText(QCoreApplication::translate("MainWindow", "&New Request", nullptr));
        BNexportReq->setText(QCoreApplication::translate("MainWindow", "&Export", nullptr));
        BNimportReq->setText(QCoreApplication::translate("MainWindow", "&Import", nullptr));
        BNdetailsReq->setText(QCoreApplication::translate("MainWindow", "&Show Details", nullptr));
        BNdeleteReq->setText(QCoreApplication::translate("MainWindow", "&Delete", nullptr));
        tabView->setTabText(tabView->indexOf(CSRTab), QCoreApplication::translate("MainWindow", "Certificate signing requests", nullptr));
        BNnewCert->setText(QCoreApplication::translate("MainWindow", "&New Certificate", nullptr));
        BNexportCert->setText(QCoreApplication::translate("MainWindow", "&Export", nullptr));
        BNimportCert->setText(QCoreApplication::translate("MainWindow", "&Import", nullptr));
        BNdetailsCert->setText(QCoreApplication::translate("MainWindow", "&Show Details", nullptr));
        BNdeleteCert->setText(QCoreApplication::translate("MainWindow", "&Delete", nullptr));
        BNimportPKCS12->setText(QCoreApplication::translate("MainWindow", "Import &PKCS#12", nullptr));
        BNimportPKCS7->setText(QCoreApplication::translate("MainWindow", "Import P&KCS#7", nullptr));
        BNviewState->setText(QCoreApplication::translate("MainWindow", "Plain View", nullptr));
        tabView->setTabText(tabView->indexOf(CertTab), QCoreApplication::translate("MainWindow", "Certificates", nullptr));
        BNnewTemp->setText(QCoreApplication::translate("MainWindow", "&New Template", nullptr));
        BNchangeTemp->setText(QCoreApplication::translate("MainWindow", "Ch&ange Template", nullptr));
        BNdeleteTemp->setText(QCoreApplication::translate("MainWindow", "&Delete", nullptr));
        BNimportTemp->setText(QCoreApplication::translate("MainWindow", "&Import", nullptr));
        BNexportTemp->setText(QCoreApplication::translate("MainWindow", "&Export", nullptr));
        tabView->setTabText(tabView->indexOf(TemplateTab), QCoreApplication::translate("MainWindow", "Templates", nullptr));
        BNnewCrl->setText(QCoreApplication::translate("MainWindow", "&New CRL", nullptr));
        BNexportCrl->setText(QCoreApplication::translate("MainWindow", "&Export", nullptr));
        BNimportCrl->setText(QCoreApplication::translate("MainWindow", "&Import", nullptr));
        BNdetailsCrl->setText(QCoreApplication::translate("MainWindow", "&Show Details", nullptr));
        BNdeleteCrl->setText(QCoreApplication::translate("MainWindow", "&Delete", nullptr));
        tabView->setTabText(tabView->indexOf(CRLTab), QCoreApplication::translate("MainWindow", "Revocation lists", nullptr));
        (void)MainWindow;
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
