/********************************************************************************
** Form generated from reading UI file 'NewKey.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWKEY_H
#define UI_NEWKEY_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_NewKey
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QLabel *TextLabel6;
    QSpacerItem *spacerItem;
    QLabel *image;
    QLabel *TextLabel1;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *TextLabel5;
    QLineEdit *keyDesc;
    QComboBox *keyType;
    QComboBox *curveBox;
    QLabel *curveLabel;
    QLabel *keySizeLabel;
    QComboBox *keyLength;
    QLabel *TextLabel1_2;
    QCheckBox *rememberDefault;
    QSpacerItem *spacerItem1;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NewKey)
    {
        if (NewKey->objectName().isEmpty())
            NewKey->setObjectName("NewKey");
        NewKey->resize(449, 320);
        verticalLayout = new QVBoxLayout(NewKey);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        TextLabel6 = new QLabel(NewKey);
        TextLabel6->setObjectName("TextLabel6");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        TextLabel6->setFont(font);

        hboxLayout->addWidget(TextLabel6);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(NewKey);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout->addLayout(hboxLayout);

        TextLabel1 = new QLabel(NewKey);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setWordWrap(true);

        verticalLayout->addWidget(TextLabel1);

        groupBox = new QGroupBox(NewKey);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        TextLabel5 = new QLabel(groupBox);
        TextLabel5->setObjectName("TextLabel5");

        gridLayout->addWidget(TextLabel5, 0, 0, 1, 2);

        keyDesc = new QLineEdit(groupBox);
        keyDesc->setObjectName("keyDesc");
        keyDesc->setMinimumSize(QSize(0, 0));
        keyDesc->setMaximumSize(QSize(32767, 32767));

        gridLayout->addWidget(keyDesc, 0, 2, 2, 1);

        keyType = new QComboBox(groupBox);
        keyType->setObjectName("keyType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(keyType->sizePolicy().hasHeightForWidth());
        keyType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(keyType, 2, 2, 1, 1);

        curveBox = new QComboBox(groupBox);
        curveBox->setObjectName("curveBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(curveBox->sizePolicy().hasHeightForWidth());
        curveBox->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(curveBox, 5, 2, 1, 1);

        curveLabel = new QLabel(groupBox);
        curveLabel->setObjectName("curveLabel");

        gridLayout->addWidget(curveLabel, 5, 1, 1, 1);

        keySizeLabel = new QLabel(groupBox);
        keySizeLabel->setObjectName("keySizeLabel");

        gridLayout->addWidget(keySizeLabel, 4, 1, 1, 1);

        keyLength = new QComboBox(groupBox);
        keyLength->setObjectName("keyLength");
        sizePolicy.setHeightForWidth(keyLength->sizePolicy().hasHeightForWidth());
        keyLength->setSizePolicy(sizePolicy);

        gridLayout->addWidget(keyLength, 4, 2, 1, 1);

        TextLabel1_2 = new QLabel(groupBox);
        TextLabel1_2->setObjectName("TextLabel1_2");

        gridLayout->addWidget(TextLabel1_2, 2, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        rememberDefault = new QCheckBox(NewKey);
        rememberDefault->setObjectName("rememberDefault");

        verticalLayout->addWidget(rememberDefault);

        spacerItem1 = new QSpacerItem(351, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem1);

        buttonBox = new QDialogButtonBox(NewKey);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(keyDesc, keyType);
        QWidget::setTabOrder(keyType, keyLength);
        QWidget::setTabOrder(keyLength, curveBox);

        retranslateUi(NewKey);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NewKey, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NewKey, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(NewKey);
    } // setupUi

    void retranslateUi(QDialog *NewKey)
    {
        NewKey->setWindowTitle(QString());
        TextLabel6->setText(QCoreApplication::translate("NewKey", "New Key", nullptr));
        image->setText(QString());
        TextLabel1->setText(QCoreApplication::translate("NewKey", "Please give a name to the new key and select the desired keysize", nullptr));
        groupBox->setTitle(QCoreApplication::translate("NewKey", "Key properties", nullptr));
        TextLabel5->setText(QCoreApplication::translate("NewKey", "Name", nullptr));
#if QT_CONFIG(tooltip)
        keyDesc->setToolTip(QCoreApplication::translate("NewKey", "The internal name of the new key", nullptr));
#endif // QT_CONFIG(tooltip)
        keyDesc->setText(QCoreApplication::translate("NewKey", "New Key", nullptr));
        curveLabel->setText(QCoreApplication::translate("NewKey", "Curve name", nullptr));
        keySizeLabel->setText(QCoreApplication::translate("NewKey", "Keysize", nullptr));
#if QT_CONFIG(tooltip)
        keyLength->setToolTip(QCoreApplication::translate("NewKey", "Usually at least 2048 bit keys are recommended", nullptr));
#endif // QT_CONFIG(tooltip)
        TextLabel1_2->setText(QCoreApplication::translate("NewKey", "Keytype", nullptr));
        rememberDefault->setText(QCoreApplication::translate("NewKey", "Remember as default", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewKey: public Ui_NewKey {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NEWKEY_H
