/********************************************************************************
** Form generated from reading UI file 'SelectToken.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTTOKEN_H
#define UI_SELECTTOKEN_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SelectToken
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QLabel *TextLabel6;
    QSpacerItem *spacerItem;
    QLabel *image;
    QLabel *TextLabel1;
    QComboBox *tokenBox;
    QSpacerItem *spacerItem1;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SelectToken)
    {
        if (SelectToken->objectName().isEmpty())
            SelectToken->setObjectName("SelectToken");
        SelectToken->resize(369, 162);
        verticalLayout = new QVBoxLayout(SelectToken);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        TextLabel6 = new QLabel(SelectToken);
        TextLabel6->setObjectName("TextLabel6");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        TextLabel6->setFont(font);

        hboxLayout->addWidget(TextLabel6);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(SelectToken);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout->addLayout(hboxLayout);

        TextLabel1 = new QLabel(SelectToken);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(TextLabel1);

        tokenBox = new QComboBox(SelectToken);
        tokenBox->setObjectName("tokenBox");

        verticalLayout->addWidget(tokenBox);

        spacerItem1 = new QSpacerItem(351, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem1);

        buttonBox = new QDialogButtonBox(SelectToken);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SelectToken);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SelectToken, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SelectToken, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SelectToken);
    } // setupUi

    void retranslateUi(QDialog *SelectToken)
    {
        SelectToken->setWindowTitle(QString());
        TextLabel6->setText(QCoreApplication::translate("SelectToken", "Security token", nullptr));
        image->setText(QString());
        TextLabel1->setText(QCoreApplication::translate("SelectToken", "Please select the security token", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SelectToken: public Ui_SelectToken {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SELECTTOKEN_H
