/********************************************************************************
** Form generated from reading UI file 'OpenDb.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENDB_H
#define UI_OPENDB_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_OpenDb
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *_2;
    QLabel *TextLabel6;
    QSpacerItem *spacerItem;
    QLabel *image;
    QSpacerItem *verticalSpacer;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *dbType;
    QLabel *label_2;
    QLineEdit *hostName;
    QLabel *label_3;
    QLineEdit *userName;
    QLabel *label_5;
    QLineEdit *dbPassword;
    QLabel *dbName_label;
    QLineEdit *dbName;
    QLabel *label_6;
    QLineEdit *prefix;
    QSpacerItem *verticalSpacer_2;
    QFrame *line;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Dialog)
    {
        if (Dialog->objectName().isEmpty())
            Dialog->setObjectName("Dialog");
        Dialog->resize(441, 292);
        verticalLayout = new QVBoxLayout(Dialog);
        verticalLayout->setObjectName("verticalLayout");
        _2 = new QHBoxLayout();
#ifndef Q_OS_MAC
        _2->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        _2->setContentsMargins(0, 0, 0, 0);
#endif
        _2->setObjectName("_2");
        TextLabel6 = new QLabel(Dialog);
        TextLabel6->setObjectName("TextLabel6");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        TextLabel6->setFont(font);

        _2->addWidget(TextLabel6);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _2->addItem(spacerItem);

        image = new QLabel(Dialog);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        _2->addWidget(image);


        verticalLayout->addLayout(_2);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(Dialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::LabelRole, label);

        dbType = new QComboBox(Dialog);
        dbType->setObjectName("dbType");

        formLayout->setWidget(0, QFormLayout::FieldRole, dbType);

        label_2 = new QLabel(Dialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::LabelRole, label_2);

        hostName = new QLineEdit(Dialog);
        hostName->setObjectName("hostName");

        formLayout->setWidget(1, QFormLayout::FieldRole, hostName);

        label_3 = new QLabel(Dialog);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::LabelRole, label_3);

        userName = new QLineEdit(Dialog);
        userName->setObjectName("userName");

        formLayout->setWidget(2, QFormLayout::FieldRole, userName);

        label_5 = new QLabel(Dialog);
        label_5->setObjectName("label_5");

        formLayout->setWidget(3, QFormLayout::LabelRole, label_5);

        dbPassword = new QLineEdit(Dialog);
        dbPassword->setObjectName("dbPassword");
        dbPassword->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(3, QFormLayout::FieldRole, dbPassword);

        dbName_label = new QLabel(Dialog);
        dbName_label->setObjectName("dbName_label");

        formLayout->setWidget(4, QFormLayout::LabelRole, dbName_label);

        dbName = new QLineEdit(Dialog);
        dbName->setObjectName("dbName");

        formLayout->setWidget(4, QFormLayout::FieldRole, dbName);

        label_6 = new QLabel(Dialog);
        label_6->setObjectName("label_6");

        formLayout->setWidget(5, QFormLayout::LabelRole, label_6);

        prefix = new QLineEdit(Dialog);
        prefix->setObjectName("prefix");

        formLayout->setWidget(5, QFormLayout::FieldRole, prefix);


        verticalLayout->addLayout(formLayout);

        verticalSpacer_2 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        line = new QFrame(Dialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        buttonBox = new QDialogButtonBox(Dialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(Dialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, Dialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, Dialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(Dialog);
    } // setupUi

    void retranslateUi(QDialog *Dialog)
    {
        TextLabel6->setText(QCoreApplication::translate("OpenDb", "Open remote database", nullptr));
        image->setText(QString());
        label->setText(QCoreApplication::translate("OpenDb", "Database type", nullptr));
        label_2->setText(QCoreApplication::translate("OpenDb", "Hostname", nullptr));
        label_3->setText(QCoreApplication::translate("OpenDb", "Username", nullptr));
        label_5->setText(QCoreApplication::translate("OpenDb", "Password", nullptr));
        dbName_label->setText(QCoreApplication::translate("OpenDb", "Database name", nullptr));
        label_6->setText(QCoreApplication::translate("OpenDb", "Table prefix", nullptr));
        (void)Dialog;
    } // retranslateUi

};

namespace Ui {
    class OpenDb: public Ui_OpenDb {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENDB_H
