/********************************************************************************
** Form generated from reading UI file 'SearchPkcs11.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHPKCS11_H
#define UI_SEARCHPKCS11_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SearchPkcs11
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame_2;
    QGridLayout *gridLayout;
    QLabel *TextLabel14;
    QLineEdit *filename;
    QToolButton *fileBut;
    QCheckBox *subdirs;
    QPushButton *search;
    QLabel *currFile;
    QListWidget *liblist;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SearchPkcs11)
    {
        if (SearchPkcs11->objectName().isEmpty())
            SearchPkcs11->setObjectName("SearchPkcs11");
        SearchPkcs11->resize(480, 378);
        verticalLayout = new QVBoxLayout(SearchPkcs11);
        verticalLayout->setObjectName("verticalLayout");
        frame_2 = new QFrame(SearchPkcs11);
        frame_2->setObjectName("frame_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy);
        frame_2->setFrameShape(QFrame::Box);
        frame_2->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(frame_2);
        gridLayout->setObjectName("gridLayout");
        TextLabel14 = new QLabel(frame_2);
        TextLabel14->setObjectName("TextLabel14");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(TextLabel14->sizePolicy().hasHeightForWidth());
        TextLabel14->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(TextLabel14, 0, 0, 1, 1);

        filename = new QLineEdit(frame_2);
        filename->setObjectName("filename");

        gridLayout->addWidget(filename, 0, 1, 1, 1);

        fileBut = new QToolButton(frame_2);
        fileBut->setObjectName("fileBut");
        sizePolicy1.setHeightForWidth(fileBut->sizePolicy().hasHeightForWidth());
        fileBut->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(fileBut, 0, 2, 1, 1);

        subdirs = new QCheckBox(frame_2);
        subdirs->setObjectName("subdirs");

        gridLayout->addWidget(subdirs, 1, 0, 1, 2);

        search = new QPushButton(frame_2);
        search->setObjectName("search");

        gridLayout->addWidget(search, 1, 2, 1, 1);


        verticalLayout->addWidget(frame_2);

        currFile = new QLabel(SearchPkcs11);
        currFile->setObjectName("currFile");
        currFile->setText(QString::fromUtf8(""));
        currFile->setTextFormat(Qt::PlainText);
        currFile->setWordWrap(false);

        verticalLayout->addWidget(currFile);

        liblist = new QListWidget(SearchPkcs11);
        liblist->setObjectName("liblist");
        liblist->setEditTriggers(QAbstractItemView::NoEditTriggers);
        liblist->setProperty("showDropIndicator", QVariant(false));

        verticalLayout->addWidget(liblist);

        buttonBox = new QDialogButtonBox(SearchPkcs11);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Open);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SearchPkcs11);
        QObject::connect(buttonBox, SIGNAL(clicked(QAbstractButton*)), SearchPkcs11, SLOT(buttonPress(QAbstractButton*)));
        QObject::connect(liblist, SIGNAL(itemDoubleClicked(QListWidgetItem*)), SearchPkcs11, SLOT(loadItem(QListWidgetItem*)));

        QMetaObject::connectSlotsByName(SearchPkcs11);
    } // setupUi

    void retranslateUi(QDialog *SearchPkcs11)
    {
        SearchPkcs11->setWindowTitle(QString());
        TextLabel14->setText(QCoreApplication::translate("SearchPkcs11", "Directory", nullptr));
        fileBut->setText(QCoreApplication::translate("SearchPkcs11", "...", nullptr));
        subdirs->setText(QCoreApplication::translate("SearchPkcs11", "Include subdirectories", nullptr));
        search->setText(QCoreApplication::translate("SearchPkcs11", "Search", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SearchPkcs11: public Ui_SearchPkcs11 {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHPKCS11_H
