/****************************************************************************
** Meta object code from reading C++ file 'CertTreeView.h'
**
** Created by: The Qt Meta Object Compiler version 68 (Qt 6.8.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../widgets/CertTreeView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CertTreeView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 68
#error "This file was generated using the moc from 6.8.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12CertTreeViewE_t {};
} // unnamed namespace


#ifdef QT_MOC_HAS_STRINGDATA
static constexpr auto qt_meta_stringdata_ZN12CertTreeViewE = QtMocHelpers::stringData(
    "CertTreeView",
    "changeView",
    "",
    "toRequest",
    "toCertificate",
    "toToken",
    "toOtherToken",
    "genCrl",
    "loadPKCS7",
    "loadPKCS12",
    "deleteFromToken",
    "manageRevocations",
    "certRenewal",
    "caProperties",
    "revoke",
    "unRevoke",
    "load",
    "loadTaKey",
    "toggleHideExpired"
);
#else  // !QT_MOC_HAS_STRINGDATA
#error "qtmochelpers.h not found or too old."
#endif // !QT_MOC_HAS_STRINGDATA

Q_CONSTINIT static const uint qt_meta_data_ZN12CertTreeViewE[] = {

 // content:
      12,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags, initial metatype offsets
       1,    0,  116,    2, 0x0a,    1 /* Public */,
       3,    0,  117,    2, 0x0a,    2 /* Public */,
       4,    0,  118,    2, 0x0a,    3 /* Public */,
       5,    0,  119,    2, 0x0a,    4 /* Public */,
       6,    0,  120,    2, 0x0a,    5 /* Public */,
       7,    0,  121,    2, 0x0a,    6 /* Public */,
       8,    0,  122,    2, 0x0a,    7 /* Public */,
       9,    0,  123,    2, 0x0a,    8 /* Public */,
      10,    0,  124,    2, 0x0a,    9 /* Public */,
      11,    0,  125,    2, 0x0a,   10 /* Public */,
      12,    0,  126,    2, 0x0a,   11 /* Public */,
      13,    0,  127,    2, 0x0a,   12 /* Public */,
      14,    0,  128,    2, 0x0a,   13 /* Public */,
      15,    0,  129,    2, 0x0a,   14 /* Public */,
      16,    0,  130,    2, 0x0a,   15 /* Public */,
      17,    0,  131,    2, 0x0a,   16 /* Public */,
      18,    1,  132,    2, 0x0a,   17 /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

Q_CONSTINIT const QMetaObject CertTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<X509SuperTreeView::staticMetaObject>(),
    qt_meta_stringdata_ZN12CertTreeViewE.offsetsAndSizes,
    qt_meta_data_ZN12CertTreeViewE,
    qt_static_metacall,
    nullptr,
    qt_incomplete_metaTypeArray<qt_meta_tag_ZN12CertTreeViewE_t,
        // Q_OBJECT / Q_GADGET
        QtPrivate::TypeAndForceComplete<CertTreeView, std::true_type>,
        // method 'changeView'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'toRequest'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'toCertificate'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'toToken'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'toOtherToken'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'genCrl'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'loadPKCS7'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'loadPKCS12'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'deleteFromToken'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'manageRevocations'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'certRenewal'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'caProperties'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'revoke'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'unRevoke'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'load'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'loadTaKey'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'toggleHideExpired'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<bool, std::false_type>
    >,
    nullptr
} };

void CertTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CertTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changeView(); break;
        case 1: _t->toRequest(); break;
        case 2: _t->toCertificate(); break;
        case 3: _t->toToken(); break;
        case 4: _t->toOtherToken(); break;
        case 5: _t->genCrl(); break;
        case 6: _t->loadPKCS7(); break;
        case 7: _t->loadPKCS12(); break;
        case 8: _t->deleteFromToken(); break;
        case 9: _t->manageRevocations(); break;
        case 10: _t->certRenewal(); break;
        case 11: _t->caProperties(); break;
        case 12: _t->revoke(); break;
        case 13: _t->unRevoke(); break;
        case 14: _t->load(); break;
        case 15: _t->loadTaKey(); break;
        case 16: _t->toggleHideExpired((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *CertTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CertTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ZN12CertTreeViewE.stringdata0))
        return static_cast<void*>(this);
    return X509SuperTreeView::qt_metacast(_clname);
}

int CertTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = X509SuperTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
