/****************************************************************************
** Meta object code from reading C++ file 'NewX509.h'
**
** Created by: The Qt Meta Object Compiler version 68 (Qt 6.8.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../widgets/NewX509.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'NewX509.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 68
#error "This file was generated using the moc from 6.8.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7NewX509E_t {};
} // unnamed namespace


#ifdef QT_MOC_HAS_STRINGDATA
static constexpr auto qt_meta_stringdata_ZN7NewX509E = QtMocHelpers::stringData(
    "NewX509",
    "on_fromReqCB_clicked",
    "",
    "on_keyList_currentIndexChanged",
    "on_reqList_currentIndexChanged",
    "newKeyDone",
    "pki_key*",
    "nkey",
    "on_applyTime_clicked",
    "on_editNameCons_clicked",
    "on_editSubAlt_clicked",
    "on_editIssAlt_clicked",
    "on_editCrlDist_clicked",
    "on_editAuthInfAcc_clicked",
    "on_foreignSignRB_toggled",
    "checked",
    "on_genKeyBut_clicked",
    "on_showReqBut_clicked",
    "on_certList_currentIndexChanged",
    "index",
    "on_applyTemplate_clicked",
    "on_applySubject_clicked",
    "on_applyExtensions_clicked",
    "on_adv_validate_clicked",
    "on_usedKeysToo_toggled",
    "on_tabWidget_currentChanged",
    "idx",
    "on_reqSubChange_clicked",
    "accept",
    "itemChanged",
    "pki_base*",
    "setupExtDNwidget",
    "s",
    "QLineEdit*",
    "w",
    "checkNameConstraints",
    "text",
    "checkSubAltName",
    "checkIssAltName",
    "checkCrlDist",
    "checkAuthInfAcc"
);
#else  // !QT_MOC_HAS_STRINGDATA
#error "qtmochelpers.h not found or too old."
#endif // !QT_MOC_HAS_STRINGDATA

Q_CONSTINIT static const uint qt_meta_data_ZN7NewX509E[] = {

 // content:
      12,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags, initial metatype offsets
       1,    0,  188,    2, 0x0a,    1 /* Public */,
       3,    1,  189,    2, 0x0a,    2 /* Public */,
       4,    1,  192,    2, 0x0a,    4 /* Public */,
       5,    1,  195,    2, 0x0a,    6 /* Public */,
       8,    0,  198,    2, 0x0a,    8 /* Public */,
       9,    0,  199,    2, 0x0a,    9 /* Public */,
      10,    0,  200,    2, 0x0a,   10 /* Public */,
      11,    0,  201,    2, 0x0a,   11 /* Public */,
      12,    0,  202,    2, 0x0a,   12 /* Public */,
      13,    0,  203,    2, 0x0a,   13 /* Public */,
      14,    1,  204,    2, 0x0a,   14 /* Public */,
      16,    0,  207,    2, 0x0a,   16 /* Public */,
      17,    0,  208,    2, 0x0a,   17 /* Public */,
      18,    1,  209,    2, 0x0a,   18 /* Public */,
      20,    0,  212,    2, 0x0a,   20 /* Public */,
      21,    0,  213,    2, 0x0a,   21 /* Public */,
      22,    0,  214,    2, 0x0a,   22 /* Public */,
      23,    0,  215,    2, 0x0a,   23 /* Public */,
      24,    1,  216,    2, 0x0a,   24 /* Public */,
      25,    1,  219,    2, 0x0a,   26 /* Public */,
      27,    0,  222,    2, 0x0a,   28 /* Public */,
      28,    0,  223,    2, 0x0a,   29 /* Public */,
      29,    1,  224,    2, 0x0a,   30 /* Public */,
      31,    2,  227,    2, 0x0a,   32 /* Public */,
      35,    1,  232,    2, 0x0a,   35 /* Public */,
      37,    1,  235,    2, 0x0a,   37 /* Public */,
      38,    1,  238,    2, 0x0a,   39 /* Public */,
      39,    1,  241,    2, 0x0a,   41 /* Public */,
      40,    1,  244,    2, 0x0a,   43 /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 30,    2,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 33,   32,   34,
    QMetaType::Void, QMetaType::QString,   36,
    QMetaType::Void, QMetaType::QString,   36,
    QMetaType::Void, QMetaType::QString,   36,
    QMetaType::Void, QMetaType::QString,   36,
    QMetaType::Void, QMetaType::QString,   36,

       0        // eod
};

Q_CONSTINIT const QMetaObject NewX509::staticMetaObject = { {
    QMetaObject::SuperData::link<XcaDetail::staticMetaObject>(),
    qt_meta_stringdata_ZN7NewX509E.offsetsAndSizes,
    qt_meta_data_ZN7NewX509E,
    qt_static_metacall,
    nullptr,
    qt_incomplete_metaTypeArray<qt_meta_tag_ZN7NewX509E_t,
        // Q_OBJECT / Q_GADGET
        QtPrivate::TypeAndForceComplete<NewX509, std::true_type>,
        // method 'on_fromReqCB_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_keyList_currentIndexChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'on_reqList_currentIndexChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'newKeyDone'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<pki_key *, std::false_type>,
        // method 'on_applyTime_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_editNameCons_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_editSubAlt_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_editIssAlt_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_editCrlDist_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_editAuthInfAcc_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_foreignSignRB_toggled'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<bool, std::false_type>,
        // method 'on_genKeyBut_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_showReqBut_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_certList_currentIndexChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'on_applyTemplate_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_applySubject_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_applyExtensions_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_adv_validate_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'on_usedKeysToo_toggled'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<bool, std::false_type>,
        // method 'on_tabWidget_currentChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'on_reqSubChange_clicked'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'accept'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'itemChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<pki_base *, std::false_type>,
        // method 'setupExtDNwidget'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        QtPrivate::TypeAndForceComplete<QLineEdit *, std::false_type>,
        // method 'checkNameConstraints'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'checkSubAltName'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'checkIssAltName'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'checkCrlDist'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'checkAuthInfAcc'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>
    >,
    nullptr
} };

void NewX509::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NewX509 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->on_fromReqCB_clicked(); break;
        case 1: _t->on_keyList_currentIndexChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->on_reqList_currentIndexChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->newKeyDone((*reinterpret_cast< std::add_pointer_t<pki_key*>>(_a[1]))); break;
        case 4: _t->on_applyTime_clicked(); break;
        case 5: _t->on_editNameCons_clicked(); break;
        case 6: _t->on_editSubAlt_clicked(); break;
        case 7: _t->on_editIssAlt_clicked(); break;
        case 8: _t->on_editCrlDist_clicked(); break;
        case 9: _t->on_editAuthInfAcc_clicked(); break;
        case 10: _t->on_foreignSignRB_toggled((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->on_genKeyBut_clicked(); break;
        case 12: _t->on_showReqBut_clicked(); break;
        case 13: _t->on_certList_currentIndexChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->on_applyTemplate_clicked(); break;
        case 15: _t->on_applySubject_clicked(); break;
        case 16: _t->on_applyExtensions_clicked(); break;
        case 17: _t->on_adv_validate_clicked(); break;
        case 18: _t->on_usedKeysToo_toggled((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->on_tabWidget_currentChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->on_reqSubChange_clicked(); break;
        case 21: _t->accept(); break;
        case 22: _t->itemChanged((*reinterpret_cast< std::add_pointer_t<pki_base*>>(_a[1]))); break;
        case 23: _t->setupExtDNwidget((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QLineEdit*>>(_a[2]))); break;
        case 24: _t->checkNameConstraints((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->checkSubAltName((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->checkIssAltName((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->checkCrlDist((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->checkAuthInfAcc((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *NewX509::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NewX509::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ZN7NewX509E.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::NewX509"))
        return static_cast< Ui::NewX509*>(this);
    return XcaDetail::qt_metacast(_clname);
}

int NewX509::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XcaDetail::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
