/********************************************************************************
** Form generated from reading UI file 'RevocationList.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REVOCATIONLIST_H
#define UI_REVOCATIONLIST_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_RevocationList
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QSpacerItem *spacerItem;
    QLabel *image;
    QHBoxLayout *horizontalLayout_2;
    QTreeWidget *certList;
    QVBoxLayout *verticalLayout;
    QPushButton *addRev;
    QPushButton *delRev;
    QPushButton *editRev;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *RevocationList)
    {
        if (RevocationList->objectName().isEmpty())
            RevocationList->setObjectName("RevocationList");
        RevocationList->resize(628, 320);
        verticalLayout_2 = new QVBoxLayout(RevocationList);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(RevocationList);
        label_3->setObjectName("label_3");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        label_3->setFont(font);

        horizontalLayout->addWidget(label_3);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem);

        image = new QLabel(RevocationList);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        horizontalLayout->addWidget(image);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        certList = new QTreeWidget(RevocationList);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        certList->setHeaderItem(__qtreewidgetitem);
        certList->setObjectName("certList");
        certList->setAlternatingRowColors(true);
        certList->setSelectionMode(QAbstractItemView::MultiSelection);
        certList->setSelectionBehavior(QAbstractItemView::SelectRows);

        horizontalLayout_2->addWidget(certList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        addRev = new QPushButton(RevocationList);
        addRev->setObjectName("addRev");

        verticalLayout->addWidget(addRev);

        delRev = new QPushButton(RevocationList);
        delRev->setObjectName("delRev");

        verticalLayout->addWidget(delRev);

        editRev = new QPushButton(RevocationList);
        editRev->setObjectName("editRev");

        verticalLayout->addWidget(editRev);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(RevocationList);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(RevocationList);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, RevocationList, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, RevocationList, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(RevocationList);
    } // setupUi

    void retranslateUi(QDialog *RevocationList)
    {
        label_3->setText(QCoreApplication::translate("RevocationList", "Manage revocations", nullptr));
        addRev->setText(QCoreApplication::translate("RevocationList", "Add", nullptr));
        delRev->setText(QCoreApplication::translate("RevocationList", "Delete", nullptr));
        editRev->setText(QCoreApplication::translate("RevocationList", "Edit", nullptr));
        (void)RevocationList;
    } // retranslateUi

};

namespace Ui {
    class RevocationList: public Ui_RevocationList {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_REVOCATIONLIST_H
