/********************************************************************************
** Form generated from reading UI file 'XcaDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XCADIALOG_H
#define UI_XCADIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_XcaDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QLabel *title;
    QSpacerItem *spacerItem;
    QLabel *image;
    QSpacerItem *topSpacer;
    QVBoxLayout *content;
    QLabel *description;
    QSpacerItem *bottomSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *XcaDialog)
    {
        if (XcaDialog->objectName().isEmpty())
            XcaDialog->setObjectName("XcaDialog");
        XcaDialog->resize(435, 177);
        verticalLayout = new QVBoxLayout(XcaDialog);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setSizeConstraint(QLayout::SetMinimumSize);
        title = new QLabel(XcaDialog);
        title->setObjectName("title");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(title->sizePolicy().hasHeightForWidth());
        title->setSizePolicy(sizePolicy);
        title->setMinimumSize(QSize(95, 40));
        title->setMaximumSize(QSize(16777215, 40));
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        title->setFont(font);
#if QT_CONFIG(tooltip)
        title->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        title->setText(QString::fromUtf8(""));
        title->setScaledContents(true);

        hboxLayout->addWidget(title);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        image = new QLabel(XcaDialog);
        image->setObjectName("image");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(image->sizePolicy().hasHeightForWidth());
        image->setSizePolicy(sizePolicy1);
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        hboxLayout->addWidget(image);


        verticalLayout->addLayout(hboxLayout);

        topSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(topSpacer);

        content = new QVBoxLayout();
        content->setObjectName("content");
        description = new QLabel(XcaDialog);
        description->setObjectName("description");

        content->addWidget(description);


        verticalLayout->addLayout(content);

        bottomSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(bottomSpacer);

        buttonBox = new QDialogButtonBox(XcaDialog);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy2);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(XcaDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, XcaDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, XcaDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(XcaDialog);
    } // setupUi

    void retranslateUi(QDialog *XcaDialog)
    {
        XcaDialog->setWindowTitle(QString());
        image->setText(QString());
        description->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class XcaDialog: public Ui_XcaDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_XCADIALOG_H
