/********************************************************************************
** Form generated from reading UI file 'Options.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/FocusCombo.h"
#include "widgets/hashBox.h"
#include "widgets/pkcs12EncBox.h"

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout_3;
    QLabel *TextLabel1;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *hboxLayout;
    QLabel *label_3;
    hashBox *hashAlgo;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_6;
    pkcs12EncBox *pkcs12EncAlgo;
    QHBoxLayout *hboxLayout1;
    QLabel *label;
    QComboBox *mbstring;
    QCheckBox *suppress;
    QCheckBox *disableNetscape;
    QCheckBox *transDnEntries;
    QCheckBox *onlyTokenHashes;
    QCheckBox *noColorize;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLineEdit *cert_expiry_num;
    focusCombo *cert_expiry_unit;
    focusCombo *ical_expiry_unit;
    QLineEdit *ical_expiry_num;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_5;
    QSpinBox *serial_len;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *vboxLayout;
    QComboBox *extDNobj;
    QListWidget *extDNlist;
    QVBoxLayout *verticalLayout_2;
    QPushButton *extDNadd;
    QPushButton *extDNdel;
    QSpacerItem *spacerItem;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *_2;
    QComboBox *expDNobj;
    QListWidget *expDNlist;
    QCheckBox *adapt_explicit_subj;
    QVBoxLayout *verticalLayout_4;
    QPushButton *expDNadd;
    QPushButton *expDNdel;
    QPushButton *expDNdefault;
    QSpacerItem *spacerItem1;
    QWidget *tab_3;
    QHBoxLayout *horizontalLayout_2;
    QListView *pkcs11List;
    QVBoxLayout *verticalLayout;
    QPushButton *addButton;
    QPushButton *removeButton;
    QPushButton *searchPkcs11;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName("Options");
        Options->resize(635, 500);
        verticalLayout_3 = new QVBoxLayout(Options);
        verticalLayout_3->setObjectName("verticalLayout_3");
        TextLabel1 = new QLabel(Options);
        TextLabel1->setObjectName("TextLabel1");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        TextLabel1->setFont(font);
        TextLabel1->setAlignment(Qt::AlignCenter);

        verticalLayout_3->addWidget(TextLabel1);

        tabWidget = new QTabWidget(Options);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_6 = new QVBoxLayout(tab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_3 = new QLabel(tab);
        label_3->setObjectName("label_3");

        hboxLayout->addWidget(label_3);

        hashAlgo = new hashBox(tab);
        hashAlgo->setObjectName("hashAlgo");

        hboxLayout->addWidget(hashAlgo);


        verticalLayout_6->addLayout(hboxLayout);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_6 = new QLabel(tab);
        label_6->setObjectName("label_6");

        horizontalLayout_5->addWidget(label_6);

        pkcs12EncAlgo = new pkcs12EncBox(tab);
        pkcs12EncAlgo->setObjectName("pkcs12EncAlgo");

        horizontalLayout_5->addWidget(pkcs12EncAlgo);


        verticalLayout_6->addLayout(horizontalLayout_5);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label = new QLabel(tab);
        label->setObjectName("label");

        hboxLayout1->addWidget(label);

        mbstring = new QComboBox(tab);
        mbstring->setObjectName("mbstring");

        hboxLayout1->addWidget(mbstring);


        verticalLayout_6->addLayout(hboxLayout1);

        suppress = new QCheckBox(tab);
        suppress->setObjectName("suppress");

        verticalLayout_6->addWidget(suppress);

        disableNetscape = new QCheckBox(tab);
        disableNetscape->setObjectName("disableNetscape");

        verticalLayout_6->addWidget(disableNetscape);

        transDnEntries = new QCheckBox(tab);
        transDnEntries->setObjectName("transDnEntries");

        verticalLayout_6->addWidget(transDnEntries);

        onlyTokenHashes = new QCheckBox(tab);
        onlyTokenHashes->setObjectName("onlyTokenHashes");

        verticalLayout_6->addWidget(onlyTokenHashes);

        noColorize = new QCheckBox(tab);
        noColorize->setObjectName("noColorize");

        verticalLayout_6->addWidget(noColorize);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_2, 0, 0, 1, 2);

        cert_expiry_num = new QLineEdit(tab);
        cert_expiry_num->setObjectName("cert_expiry_num");

        gridLayout->addWidget(cert_expiry_num, 0, 2, 1, 1);

        cert_expiry_unit = new focusCombo(tab);
        cert_expiry_unit->setObjectName("cert_expiry_unit");

        gridLayout->addWidget(cert_expiry_unit, 0, 3, 1, 1);

        ical_expiry_unit = new focusCombo(tab);
        ical_expiry_unit->setObjectName("ical_expiry_unit");

        gridLayout->addWidget(ical_expiry_unit, 1, 3, 1, 1);

        ical_expiry_num = new QLineEdit(tab);
        ical_expiry_num->setObjectName("ical_expiry_num");

        gridLayout->addWidget(ical_expiry_num, 1, 2, 1, 1);

        label_4 = new QLabel(tab);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 1, 0, 1, 2);


        verticalLayout_6->addLayout(gridLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_5 = new QLabel(tab);
        label_5->setObjectName("label_5");

        horizontalLayout_4->addWidget(label_5);

        serial_len = new QSpinBox(tab);
        serial_len->setObjectName("serial_len");
        serial_len->setMinimum(8);
        serial_len->setMaximum(256);
        serial_len->setSingleStep(8);
        serial_len->setValue(64);

        horizontalLayout_4->addWidget(serial_len);


        verticalLayout_6->addLayout(horizontalLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 241, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_2);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_5 = new QVBoxLayout(tab_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        groupBox = new QGroupBox(tab_2);
        groupBox->setObjectName("groupBox");
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        extDNobj = new QComboBox(groupBox);
        extDNobj->setObjectName("extDNobj");

        vboxLayout->addWidget(extDNobj);

        extDNlist = new QListWidget(groupBox);
        extDNlist->setObjectName("extDNlist");

        vboxLayout->addWidget(extDNlist);


        horizontalLayout->addLayout(vboxLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        extDNadd = new QPushButton(groupBox);
        extDNadd->setObjectName("extDNadd");

        verticalLayout_2->addWidget(extDNadd);

        extDNdel = new QPushButton(groupBox);
        extDNdel->setObjectName("extDNdel");

        verticalLayout_2->addWidget(extDNdel);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_5->addWidget(groupBox);

        groupBox_2 = new QGroupBox(tab_2);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_3 = new QHBoxLayout(groupBox_2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        _2 = new QVBoxLayout();
        _2->setObjectName("_2");
        expDNobj = new QComboBox(groupBox_2);
        expDNobj->setObjectName("expDNobj");

        _2->addWidget(expDNobj);

        expDNlist = new QListWidget(groupBox_2);
        expDNlist->setObjectName("expDNlist");
        expDNlist->setDragDropMode(QAbstractItemView::InternalMove);

        _2->addWidget(expDNlist);

        adapt_explicit_subj = new QCheckBox(groupBox_2);
        adapt_explicit_subj->setObjectName("adapt_explicit_subj");

        _2->addWidget(adapt_explicit_subj);


        horizontalLayout_3->addLayout(_2);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        expDNadd = new QPushButton(groupBox_2);
        expDNadd->setObjectName("expDNadd");

        verticalLayout_4->addWidget(expDNadd);

        expDNdel = new QPushButton(groupBox_2);
        expDNdel->setObjectName("expDNdel");

        verticalLayout_4->addWidget(expDNdel);

        expDNdefault = new QPushButton(groupBox_2);
        expDNdefault->setObjectName("expDNdefault");

        verticalLayout_4->addWidget(expDNdefault);

        spacerItem1 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(spacerItem1);


        horizontalLayout_3->addLayout(verticalLayout_4);


        verticalLayout_5->addWidget(groupBox_2);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        horizontalLayout_2 = new QHBoxLayout(tab_3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        pkcs11List = new QListView(tab_3);
        pkcs11List->setObjectName("pkcs11List");
        pkcs11List->setDragEnabled(true);
        pkcs11List->setAcceptDrops(true);
        pkcs11List->setDragDropOverwriteMode(false);
        pkcs11List->setDragDropMode(QAbstractItemView::InternalMove);
        pkcs11List->setSelectionBehavior(QAbstractItemView::SelectRows);
        pkcs11List->setMovement(QListView::Snap);
        pkcs11List->setResizeMode(QListView::Adjust);
        pkcs11List->setUniformItemSizes(true);

        horizontalLayout_2->addWidget(pkcs11List);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        addButton = new QPushButton(tab_3);
        addButton->setObjectName("addButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(addButton->sizePolicy().hasHeightForWidth());
        addButton->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(addButton);

        removeButton = new QPushButton(tab_3);
        removeButton->setObjectName("removeButton");
        sizePolicy1.setHeightForWidth(removeButton->sizePolicy().hasHeightForWidth());
        removeButton->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(removeButton);

        searchPkcs11 = new QPushButton(tab_3);
        searchPkcs11->setObjectName("searchPkcs11");

        verticalLayout->addWidget(searchPkcs11);

        verticalSpacer = new QSpacerItem(77, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout);

        tabWidget->addTab(tab_3, QString());

        verticalLayout_3->addWidget(tabWidget);

        line = new QFrame(Options);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_3->addWidget(line);

        buttonBox = new QDialogButtonBox(Options);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);


        retranslateUi(Options);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, Options, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, Options, qOverload<>(&QDialog::reject));
        QObject::connect(noColorize, &QCheckBox::toggled, cert_expiry_num, &QLineEdit::setDisabled);
        QObject::connect(noColorize, SIGNAL(toggled(bool)), cert_expiry_unit, SLOT(setDisabled(bool)));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QDialog *Options)
    {
        TextLabel1->setText(QCoreApplication::translate("Options", "XCA Options", nullptr));
        label_3->setText(QCoreApplication::translate("Options", "Default hash algorithm", nullptr));
        label_6->setText(QCoreApplication::translate("Options", "PKCS12 encryption algorithm", nullptr));
        label->setText(QCoreApplication::translate("Options", "String types", nullptr));
        suppress->setText(QCoreApplication::translate("Options", "Suppress success messages", nullptr));
        disableNetscape->setText(QCoreApplication::translate("Options", "Disable legacy Netscape extensions", nullptr));
        transDnEntries->setText(QCoreApplication::translate("Options", "Translate established x509 terms (%1 -> %2)", nullptr));
#if QT_CONFIG(tooltip)
        onlyTokenHashes->setToolTip(QCoreApplication::translate("Options", "The hashing functionality of the token is not used by XCA.\n"
"It may however honor a restricted hash-set propagated by the token.\n"
"Especially EC and DSA are only defined with SHA1 in the PKCS#11 specification.", nullptr));
#endif // QT_CONFIG(tooltip)
        onlyTokenHashes->setText(QCoreApplication::translate("Options", "Only use hashes supported by the token when signing with a token key", nullptr));
        noColorize->setText(QCoreApplication::translate("Options", "Don't colorize expired certificates", nullptr));
        label_2->setText(QCoreApplication::translate("Options", "Certificate expiry warning threshold", nullptr));
        label_4->setText(QCoreApplication::translate("Options", "Send vCalendar expiry reminder", nullptr));
        label_5->setText(QCoreApplication::translate("Options", "Serial number length", nullptr));
        serial_len->setSuffix(QCoreApplication::translate("Options", " bit", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("Options", "Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("Options", "Mandatory subject entries", nullptr));
        extDNadd->setText(QCoreApplication::translate("Options", "Add", nullptr));
        extDNdel->setText(QCoreApplication::translate("Options", "Delete", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("Options", "Explicit subject entries", nullptr));
        adapt_explicit_subj->setText(QCoreApplication::translate("Options", "Dynamically arrange explicit subject entries", nullptr));
        expDNadd->setText(QCoreApplication::translate("Options", "Add", nullptr));
        expDNdel->setText(QCoreApplication::translate("Options", "Delete", nullptr));
        expDNdefault->setText(QCoreApplication::translate("Options", "Default", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("Options", "Distinguished name", nullptr));
        addButton->setText(QCoreApplication::translate("Options", "Add", nullptr));
        removeButton->setText(QCoreApplication::translate("Options", "Remove", nullptr));
        searchPkcs11->setText(QCoreApplication::translate("Options", "Search", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("Options", "PKCS#11 provider", nullptr));
        (void)Options;
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
