/********************************************************************************
** Form generated from reading UI file 'PwDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWDIALOG_H
#define UI_PWDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_PwDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *layout;
    QLabel *title;
    QSpacerItem *spc;
    QLabel *image;
    QFrame *frame_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *description;
    QFrame *frame;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *passA;
    QLabel *repeatLabel;
    QLineEdit *passB;
    QCheckBox *takeHex;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PwDialog)
    {
        if (PwDialog->objectName().isEmpty())
            PwDialog->setObjectName("PwDialog");
        PwDialog->resize(400, 264);
        verticalLayout = new QVBoxLayout(PwDialog);
        verticalLayout->setObjectName("verticalLayout");
        layout = new QHBoxLayout();
#ifndef Q_OS_MAC
        layout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        layout->setContentsMargins(0, 0, 0, 0);
#endif
        layout->setObjectName("layout");
        title = new QLabel(PwDialog);
        title->setObjectName("title");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(14);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        title->setFont(font);

        layout->addWidget(title);

        spc = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layout->addItem(spc);

        image = new QLabel(PwDialog);
        image->setObjectName("image");
        image->setMinimumSize(QSize(95, 40));
        image->setMaximumSize(QSize(95, 40));
        image->setScaledContents(true);

        layout->addWidget(image);


        verticalLayout->addLayout(layout);

        frame_2 = new QFrame(PwDialog);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::NoFrame);
        verticalLayout_2 = new QVBoxLayout(frame_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        description = new QLabel(frame_2);
        description->setObjectName("description");

        verticalLayout_2->addWidget(description);


        verticalLayout->addWidget(frame_2);

        frame = new QFrame(PwDialog);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Box);
        frame->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(frame);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        passA = new QLineEdit(frame);
        passA->setObjectName("passA");
        passA->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(passA, 0, 1, 1, 1);

        repeatLabel = new QLabel(frame);
        repeatLabel->setObjectName("repeatLabel");

        gridLayout->addWidget(repeatLabel, 1, 0, 1, 1);

        passB = new QLineEdit(frame);
        passB->setObjectName("passB");
        passB->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(passB, 1, 1, 1, 1);

        takeHex = new QCheckBox(frame);
        takeHex->setObjectName("takeHex");

        gridLayout->addWidget(takeHex, 2, 0, 1, 2);


        verticalLayout->addWidget(frame);

        buttonBox = new QDialogButtonBox(PwDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(PwDialog);
        QObject::connect(buttonBox, SIGNAL(clicked(QAbstractButton*)), PwDialog, SLOT(buttonPress(QAbstractButton*)));

        QMetaObject::connectSlotsByName(PwDialog);
    } // setupUi

    void retranslateUi(QDialog *PwDialog)
    {
#if QT_CONFIG(tooltip)
        takeHex->setToolTip(QCoreApplication::translate("PwDialog", "The password is parsed as 2-digit hex code. It must have an even number of digits (0-9 and a-f)", nullptr));
#endif // QT_CONFIG(tooltip)
        takeHex->setText(QCoreApplication::translate("PwDialog", "Take as HEX string", nullptr));
        (void)PwDialog;
    } // retranslateUi

};

namespace Ui {
    class PwDialog: public Ui_PwDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PWDIALOG_H
