/********************************************************************************
** Form generated from reading UI file 'v3ext.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_V3EXT_H
#define UI_V3EXT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "widgets/kvView.h"

QT_BEGIN_NAMESPACE

class Ui_v3ext
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *critical;
    QCheckBox *copy_cn;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    kvView *tab;
    QLabel *infoLabel;
    QVBoxLayout *vboxLayout;
    QPushButton *addEntry;
    QPushButton *delEntry;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout;
    QPushButton *apply;
    QPushButton *validate;
    QSpacerItem *spacerItem1;
    QPushButton *cancel;

    void setupUi(QDialog *v3ext)
    {
        if (v3ext->objectName().isEmpty())
            v3ext->setObjectName("v3ext");
        v3ext->resize(473, 233);
        verticalLayout_2 = new QVBoxLayout(v3ext);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        critical = new QCheckBox(v3ext);
        critical->setObjectName("critical");
        critical->setText(QString::fromUtf8("Critical"));

        horizontalLayout_2->addWidget(critical);

        copy_cn = new QCheckBox(v3ext);
        copy_cn->setObjectName("copy_cn");

        horizontalLayout_2->addWidget(copy_cn);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        tab = new kvView(v3ext);
        tab->setObjectName("tab");

        verticalLayout->addWidget(tab);

        infoLabel = new QLabel(v3ext);
        infoLabel->setObjectName("infoLabel");
        infoLabel->setFrameShape(QFrame::Panel);
        infoLabel->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(infoLabel);


        horizontalLayout->addLayout(verticalLayout);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        addEntry = new QPushButton(v3ext);
        addEntry->setObjectName("addEntry");

        vboxLayout->addWidget(addEntry);

        delEntry = new QPushButton(v3ext);
        delEntry->setObjectName("delEntry");

        vboxLayout->addWidget(delEntry);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        horizontalLayout->addLayout(vboxLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        apply = new QPushButton(v3ext);
        apply->setObjectName("apply");

        hboxLayout->addWidget(apply);

        validate = new QPushButton(v3ext);
        validate->setObjectName("validate");

        hboxLayout->addWidget(validate);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);

        cancel = new QPushButton(v3ext);
        cancel->setObjectName("cancel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cancel->sizePolicy().hasHeightForWidth());
        cancel->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(cancel);


        verticalLayout_2->addLayout(hboxLayout);


        retranslateUi(v3ext);
        QObject::connect(cancel, &QPushButton::clicked, v3ext, qOverload<>(&QDialog::reject));
        QObject::connect(delEntry, &QPushButton::clicked, tab, qOverload<>(&kvView::deleteCurrentRow));
        QObject::connect(addEntry, &QPushButton::clicked, tab, qOverload<>(&kvView::addKvRow));

        QMetaObject::connectSlotsByName(v3ext);
    } // setupUi

    void retranslateUi(QDialog *v3ext)
    {
        copy_cn->setText(QCoreApplication::translate("v3ext", "Copy Common Name", nullptr));
        addEntry->setText(QCoreApplication::translate("v3ext", "Add", nullptr));
        delEntry->setText(QCoreApplication::translate("v3ext", "Delete", nullptr));
        apply->setText(QCoreApplication::translate("v3ext", "Apply", nullptr));
        validate->setText(QCoreApplication::translate("v3ext", "Validate", nullptr));
        cancel->setText(QCoreApplication::translate("v3ext", "Cancel", nullptr));
        (void)v3ext;
    } // retranslateUi

};

namespace Ui {
    class v3ext: public Ui_v3ext {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_V3EXT_H
